'use strict';

var lr = require('@lezer/lr');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');
var autocomplete = require('@codemirror/autocomplete');

// Note that 'eval' and 'do' are not in this list as they can accept a block.
const namedUnaryOperators = [
    'abs',
    'alarm',
    'await',
    'caller',
    'chdir',
    'chr',
    'chroot',
    'close',
    'closedir',
    'cos',
    'defined',
    'delete',
    'eof',
    'evalbytes',
    'exists',
    'exit',
    'exp',
    'fileno',
    'getc',
    'gethostbyname',
    'getnetbyname',
    'getpgrp',
    'getprotobyname',
    'glob',
    'gmtime',
    'hex',
    'int',
    'lc',
    'lcfirst',
    'length',
    'localtime',
    'lock',
    'log',
    'lstat',
    'oct',
    'ord',
    'pos',
    'quotemeta',
    'rand',
    'readdir',
    'readline',
    'readlink',
    'readpipe',
    'reset',
    'rewinddir',
    'ref',
    'rmdir',
    'scalar',
    'select',
    'sin',
    'sleep',
    'sqrt',
    'srand',
    'stat',
    'tell',
    'telldir',
    'tied',
    'uc',
    'ucfirst',
    'umask',
    'undef',
    'untie'
];
// The list operators that can operate on a block (grep, map, join, sort, and unpack) are handled separately.
const listOperators = [
    'atan2',
    'chomp',
    'chop',
    'chmod',
    'chown',
    'crypt',
    'die',
    'fcntl',
    'flock',
    'getpriority',
    'index',
    'ioctl',
    'kill',
    'link',
    'mkdir',
    'open',
    'opendir',
    'pack',
    'pipe',
    'read',
    'rename',
    'reverse',
    'rindex',
    'seek',
    'seekdir',
    'setpgrp',
    'setpriority',
    'split',
    'sprintf',
    'substr',
    'symlink',
    'syscall',
    'sysopen',
    'sysread',
    'sysseek',
    'syswrite',
    'tie',
    'truncate',
    'unlink',
    'utime',
    'vec',
    'waitpid',
    'warn'
];

// This file was generated by lezer-generator. You probably shouldn't edit it.
const automaticSemicolon = 306, UnrestrictedIdentifier = 1, SpecialScalarVariable = 2, NamedUnaryOperator = 3, ListOperator = 4, FileTestOp = 5, IOOperatorStart = 6, Glob = 7, ReadonlySTDIN = 8, IOOperatorEnd = 9, HeredocStartIdentifier = 10, uninterpolatedHeredocStart = 307, interpolatedHeredocStart = 308, HeredocEndIdentifier = 11, InterpolatedStringContent = 12, EscapeSequence = 13, afterInterpolation = 309, packageNamePart = 310, afterPackageName = 311, QuoteLikeStartDelimiter = 14, QuoteLikeSeparatorDelimiter = 15, QuoteLikeEndDelimiter = 16, StringContent = 17, QWElement = 18, patternMatchStart = 312, RegexOptions = 19, regexEnd = 313, PodDirective = 20, PodContent = 21, PodCut = 22, endDataBlock = 314, q = 42, qq = 45, qw = 71, qx = 82, m = 84, qr = 88, s = 90, tr = 92, y = 93, Prototype = 111, PackageName = 121;

const isUpperCaseASCIILetter = (ch) => ch >= 65 && ch <= 90;
const isLowerCaseASCIILetter = (ch) => ch >= 97 && ch <= 122;
const isASCIILetter = (ch) => isLowerCaseASCIILetter(ch) || isUpperCaseASCIILetter(ch);
const isDigit = (ch) => ch >= 48 && ch <= 55;
const isIdentifierChar = (ch) => ch == 95 /* _ */ || isASCIILetter(ch) || isDigit(ch);
const isVariableStartChar = (ch) => ch == 95 /* _ */ || isASCIILetter(ch);
const isRegexOptionChar = (ch, regexType) => {
    if (regexType === tr || regexType === y) {
        if (ch == 99 /* c */ || ch == 100 /* d */ || ch == 115 /* s */ || ch == 114 /* r */)
            return true;
        return false;
    }
    if (ch == 109 /* m */ ||
        ch == 115 /* s */ ||
        ch == 105 /* i */ ||
        ch == 120 /* x */ ||
        ch == 112 /* p */ ||
        ch == 111 /* o */ ||
        ch == 100 /* d */ ||
        ch == 117 /* u */ ||
        ch == 97 /* a */ ||
        ch == 108 /* l */ ||
        ch == 110 /* n */)
        return true;
    if ((regexType === m || regexType === s) && (ch == 103 /* g */ || ch == 99) /* c */)
        return true;
    if (regexType == s && (ch == 101 /* e */ || ch == 114) /* r */)
        return true;
    return false;
};
// !"$%&'()*+,-./0123456789:;<=>?@[\]`~
const isSpecialVariableChar = (ch) => (ch >= 33 && ch != 35 && ch <= 64) || ch == 91 || ch == 92 || ch == 93 || ch == 96 || ch == 126;
/* 0-9, a-f, A-F */
const isHex = (ch) => (ch >= 48 && ch <= 55) || (ch >= 97 && ch <= 102) || (ch >= 65 && ch <= 70);
// ' ', \t, \n, \r
const isWhitespace = (ch) => ch == 32 || ch == 9 || ch == 10 || ch == 13;
const gobbleWhitespace = (input) => {
    while (isWhitespace(input.next))
        input.advance();
};
// rwxoRWXOezsfdlpSbctugkTBMAC
const isFileTestOperatorChar = (ch) => ch == 114 ||
    ch == 119 ||
    ch == 120 ||
    ch == 111 ||
    ch == 82 ||
    ch == 87 ||
    ch == 88 ||
    ch == 79 ||
    ch == 101 ||
    ch == 122 ||
    ch == 115 ||
    ch == 102 ||
    ch == 100 ||
    ch == 108 ||
    ch == 112 ||
    ch == 83 ||
    ch == 98 ||
    ch == 99 ||
    ch == 116 ||
    ch == 117 ||
    ch == 103 ||
    ch == 107 ||
    ch == 84 ||
    ch == 66 ||
    ch == 77 ||
    ch == 65 ||
    ch == 67;
const heredocQueue = [];
// Base class that all tracker contexts extend.
class Context {
    type;
    parent;
    stackPos;
    // Used by quote and quoteLike operators.
    startDelimiter;
    endDelimiter;
    // Used by quoteLike operators.
    quoteLikeType;
    nestLevel = 0;
    // Used by heredocs.
    tag;
    indented = false;
    inBody = false;
    newlinePos;
    // Used by any interpolating context.
    interpolating = false;
    constructor(type, parent = null, stackPos = -1, options = {}) {
        this.type = type;
        this.parent = parent;
        this.stackPos = stackPos;
        this.quoteLikeType = options.quoteLikeType;
        this.interpolating = options.interpolating ?? true;
        this.indented = options.indented ?? false;
        if (options.tag)
            this.tag = options.tag;
        if (typeof options.startDelimiter === 'number')
            this.setStartAndEndDelimiters(options.startDelimiter);
        if (typeof options.newlinePos === 'number')
            this.newlinePos = options.newlinePos;
    }
    setStartAndEndDelimiters(start) {
        this.startDelimiter = start;
        if (start == 40 /* ( */) {
            this.endDelimiter = 41 /* ) */;
        }
        else if (start == 60 /* < */) {
            this.endDelimiter = 62 /* > */;
        }
        else if (start == 91 /* [ */) {
            this.endDelimiter = 93 /* ] */;
        }
        else if (start == 123 /* { */) {
            this.endDelimiter = 125 /* } */;
        }
        else
            this.endDelimiter = start;
    }
    atEnd(input) {
        if (this.type === 'heredoc') {
            if (!this.tag || input.peek(-1) !== 10)
                return false;
            let pos = 0;
            if (this.indented) {
                let nextChar = input.peek(pos);
                while (isWhitespace(nextChar))
                    nextChar = input.peek(++pos);
            }
            for (const tagCh of this.tag) {
                if (input.peek(pos++) !== tagCh)
                    return false;
            }
            if (input.peek(pos) < 0 || input.peek(pos) == 10)
                return pos;
            return false;
        }
        else {
            return input.next === this.endDelimiter ? 1 : false;
        }
    }
}
const contextTracker = new lr.ContextTracker({
    start: new Context('root'),
    shift(context, term, stack, input) {
        if (term === q || term === qq || term === qx || term === qw) {
            return new Context('quoteLike', context, stack.pos, { quoteLikeType: term });
        }
        else if (term === m || term === qr || term === s || term === tr || term === y) {
            return new Context('quoteLike&regex', context, stack.pos, { quoteLikeType: term });
        }
        else if (term === IOOperatorStart) {
            return new Context('iooperator', context);
        }
        else if (term === HeredocStartIdentifier) {
            let pos = 0;
            const indented = input.next == 126; /* ~ */
            if (indented)
                ++pos;
            let haveWhitespace = false;
            while (isWhitespace(input.peek(pos))) {
                haveWhitespace = true;
                ++pos;
            }
            const quote = input.peek(pos) == 39 /* ' */ || input.peek(pos) == 34 /* " */ || input.peek(pos) == 96 /* ` */
                ? input.peek(pos)
                : undefined;
            if (!quote && haveWhitespace)
                return context;
            if (quote)
                ++pos;
            const backslashedTag = !quote && input.peek(pos) == 92; /* \\ */
            if (backslashedTag && (haveWhitespace || isWhitespace(input.peek(++pos))))
                return context;
            if (!isIdentifierChar(input.peek(pos)))
                return context;
            const tag = [input.peek(pos++)];
            for (;;) {
                const next = input.peek(pos++);
                if (!isIdentifierChar(next))
                    break;
                tag.push(next);
            }
            if (heredocQueue[0]?.stackPos !== stack.pos) {
                while (input.peek(pos) != 10 /* \n */ && input.peek(pos) >= 0)
                    ++pos;
                heredocQueue.unshift(new Context('heredoc', context, stack.pos, {
                    tag,
                    interpolating: (!quote || quote == 34 || quote == 96) && !backslashedTag,
                    indented,
                    newlinePos: input.pos + pos
                }));
            }
            return context;
        }
        else if (term === patternMatchStart) {
            let pos = 0;
            let next;
            while (isWhitespace((next = input.peek(pos))))
                ++pos;
            if (next == 47 /* / */) {
                return new Context('regex', context, stack.pos, { startDelimiter: 47, quoteLikeType: m });
            }
        }
        else if ((context.type !== 'quote' || input.next != context.endDelimiter) &&
            term !== InterpolatedStringContent) {
            if (input.next == 34 /* " */ || input.next == 96 /* ` */) {
                return new Context('quote', context, stack.pos, { startDelimiter: input.next });
            }
        }
        if (context.type.startsWith('quoteLike') && term === QuoteLikeStartDelimiter) {
            let pos = 1;
            let startDelimiter = input.next;
            while (isWhitespace(startDelimiter))
                startDelimiter = input.peek(pos++);
            if (startDelimiter >= 0) {
                context.setStartAndEndDelimiters(startDelimiter);
                // Note that q and qw are not interpolated, but don't need to set this because they can't accept
                // interpolated content.
                if (context.quoteLikeType === tr ||
                    context.quoteLikeType === y ||
                    ((context.quoteLikeType === m ||
                        context.quoteLikeType === qr ||
                        context.quoteLikeType === qx ||
                        context.quoteLikeType === s) &&
                        startDelimiter == 39) /* ' */)
                    context.interpolating = false;
                return context;
            }
        }
        if ((term === interpolatedHeredocStart || term === uninterpolatedHeredocStart) &&
            heredocQueue.slice(-1)[0]?.newlinePos !== context.newlinePos) {
            const heredocContext = heredocQueue.pop();
            if (heredocContext) {
                heredocContext.parent = context;
                heredocContext.inBody = true;
                return heredocContext;
            }
        }
        if (context.parent &&
            ((context.type === 'quote' && input.next === context.endDelimiter) ||
                (context.type === 'quoteLike' && term === QuoteLikeEndDelimiter) ||
                (context.type === 'regex' && term === regexEnd) ||
                (context.type === 'quoteLike&regex' && term === regexEnd) ||
                (context.type === 'heredoc' && term === HeredocEndIdentifier) ||
                (context.type === 'iooperator' && term === IOOperatorEnd))) {
            return context.parent;
        }
        return context;
    },
    strict: false
});
const semicolon = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(automaticSemicolon) && input.next != 59 /* ; */ && (input.next < 0 || input.next == 125) /* } */)
        input.acceptToken(automaticSemicolon);
});
const unrestrictedIdentifier = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(UnrestrictedIdentifier)) {
        gobbleWhitespace(input);
        if (input.next < 0 || isASCIILetter(input.next) || input.next == 95 /* _ */)
            return;
        while (input.next >= 0 && isIdentifierChar(input.next))
            input.advance();
        input.acceptToken(UnrestrictedIdentifier);
    }
});
// Note that is only to pick up special variables that won't be considered as a ScalarVariable already.
const specialScalarVariable = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(SpecialScalarVariable) && input.next == 36 /* $ */) {
        if (stack.canShift(Prototype))
            return;
        const first = input.peek(1);
        const second = input.peek(2);
        if (first == 123 /* { */ && isSpecialVariableChar(second) && input.peek(3) == 125 /* } */) {
            input.acceptToken(SpecialScalarVariable, 4);
            return;
        }
        if (first == 123 /* { */ && second == 94 /* ^ */) {
            let pos = 3, ch;
            while ((isUpperCaseASCIILetter((ch = input.peek(pos))) || ch == 95) /* _ */ && ch != 125 /* } */)
                ++pos;
            if (ch == 125) {
                input.acceptToken(SpecialScalarVariable, pos + 1);
                return;
            }
        }
        if (first == 94 /* ^ */ && (isUpperCaseASCIILetter(second) || second == 95) /* _ */) {
            input.acceptToken(SpecialScalarVariable, 3);
            return;
        }
        if (!isSpecialVariableChar(first))
            return;
        if (first == 36 /* $ */ && isIdentifierChar(second))
            return;
        input.acceptToken(SpecialScalarVariable, 2);
        return;
    }
});
// Finds the longest lower case word coming up in the stream.  Returns an array
// containing the word and the ascii character code of the next character after it.
const peekLCWord = (input) => {
    let pos = 0;
    let word = '', nextChar;
    while (isLowerCaseASCIILetter((nextChar = input.peek(pos)))) {
        ++pos;
        word += String.fromCharCode(nextChar);
    }
    return [word, nextChar];
};
const builtinOperator = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(NamedUnaryOperator)) {
        const [word, nextChar] = peekLCWord(input);
        if (namedUnaryOperators.includes(word) && !isIdentifierChar(nextChar))
            input.acceptToken(NamedUnaryOperator, word.length);
    }
    if (stack.canShift(ListOperator)) {
        const [word, nextChar] = peekLCWord(input);
        if (listOperators.includes(word) && !isIdentifierChar(nextChar))
            input.acceptToken(ListOperator, word.length);
    }
});
const fileIO = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(FileTestOp) && !stack.canShift(PackageName)) {
        gobbleWhitespace(input);
        if (input.next == 45 /* - */ && isFileTestOperatorChar(input.peek(1)) && !isASCIILetter(input.peek(2)))
            input.acceptToken(FileTestOp, 2);
    }
    // Start an IO operator if the following input contains a '<' character that is not followed by another
    // one or the following input specifically contains <<>>.
    if (stack.canShift(IOOperatorStart) &&
        input.next == 60 &&
        (input.peek(1) != 60 || (input.peek(2) == 62 && input.peek(3) == 62))) {
        input.acceptToken(IOOperatorStart, 1);
        return;
    }
    if (!(stack.context instanceof Context) || stack.context.type !== 'iooperator')
        return;
    // End the IO operator when the '>' character is encountered.
    if (stack.canShift(IOOperatorEnd) && input.next == 62) {
        input.acceptToken(IOOperatorEnd, 1);
        return;
    }
    // In this case the initial '<' started the IO operator, and what follows is '<>>'
    // to finish the read only standard input declaration.
    if (input.peek(0) == 60 && input.peek(1) == 62 && input.peek(2) == 62) {
        input.acceptToken(ReadonlySTDIN, 2);
        return;
    }
    let pos = 0, ch;
    const isPossibleVariable = input.next == 36; /* $ */
    if (isPossibleVariable)
        ++pos;
    let haveWhitespace = false, haveNonASCII = false;
    while ((ch = input.peek(pos)) >= 0 && ch != 62 /* > */) {
        if (isWhitespace(ch))
            haveWhitespace = true;
        if (!isASCIILetter(ch))
            haveNonASCII = true;
        ++pos;
    }
    if ((isPossibleVariable && !haveWhitespace && !haveNonASCII) ||
        (!isPossibleVariable && !haveWhitespace && !haveNonASCII) ||
        ch < 0)
        return;
    input.acceptToken(Glob, pos);
}, { contextual: true });
const heredoc = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(HeredocStartIdentifier)) {
        const indented = input.next == 126; /* ~ */
        if (indented)
            input.advance();
        gobbleWhitespace(input);
        const quote = input.next == 39 /* ' */ || input.next == 34 /* " */ || input.next == 96 /* ` */
            ? input.next
            : undefined;
        if (!quote && isWhitespace(input.peek(-1)))
            return;
        if (quote)
            input.advance();
        if (input.next == 92 /* \\ */ && (isWhitespace(input.peek(-1)) || isWhitespace(input.advance())))
            return;
        if (!isIdentifierChar(input.next))
            return;
        for (;;) {
            input.advance();
            if (!isIdentifierChar(input.next))
                break;
        }
        if (quote) {
            if (input.next != quote)
                return;
            input.advance();
        }
        input.acceptToken(HeredocStartIdentifier);
        return;
    }
    if (!(stack.context instanceof Context))
        return;
    if (input.next == 10 /* \n */ &&
        heredocQueue.length &&
        heredocQueue.slice(-1)[0]?.newlinePos !== stack.context.newlinePos &&
        (stack.canShift(uninterpolatedHeredocStart) || stack.canShift(interpolatedHeredocStart))) {
        if (heredocQueue.slice(-1)[0]?.interpolating)
            input.acceptToken(interpolatedHeredocStart, 1);
        else
            input.acceptToken(uninterpolatedHeredocStart, 1);
        return;
    }
    if (stack.context.type !== 'heredoc' || !stack.context.inBody)
        return;
    if (stack.context.interpolating) {
        const endCount = stack.context.atEnd(input);
        if (endCount) {
            input.acceptToken(HeredocEndIdentifier, endCount);
            return;
        }
        else if (input.next < 0) {
            input.acceptToken(HeredocEndIdentifier);
            return;
        }
    }
    else {
        const endCount = stack.context.atEnd(input);
        if (endCount) {
            input.acceptToken(HeredocEndIdentifier, endCount);
            return;
        }
        for (;;) {
            if (input.next < 0) {
                input.acceptToken(HeredocEndIdentifier);
                return;
            }
            if (input.next != 10 /* \n */) {
                input.advance();
                continue;
            }
            input.advance();
            const endCount = stack.context.atEnd(input);
            if (endCount) {
                input.acceptToken(StringContent);
                return;
            }
            input.advance();
        }
    }
}, { contextual: true });
const scanEscape = (input) => {
    const after = input.peek(1);
    // Restricted range octal character
    if (after >= 48 && after <= 55 /* 0-7 */) {
        let size = 2, next;
        while (size < 5 && (next = input.peek(size)) >= 48 && next <= 55)
            ++size;
        return size;
    }
    // Restricted range hexidecimal character
    if (after == 120 /* x */ && isHex(input.peek(2)))
        return isHex(input.peek(3)) ? 4 : 3;
    // Hexidecimal character
    if (after == 120 /* x */ && input.peek(2) == 123 /* { */) {
        // FIXME: There could be optional blanks at the beginning and end inside the braces.
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (!isHex(next))
                break;
        }
    }
    // This could be any named unicode character or character sequence.
    if (after == 78 /* N */ && input.peek(2) == 123 /* { */) {
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (next < 0)
                break;
        }
    }
    // Octal character
    if (after == 111 /* o */ && input.peek(2) == 123 /* { */) {
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (next < 48 || next > 55 /* not 0-7 */)
                break;
        }
    }
    return 2;
};
const interpolated = new lr.ExternalTokenizer((input, stack) => {
    if (!(stack.context instanceof Context) || !stack.context.interpolating)
        return;
    let content = false;
    for (;; content = true) {
        if (heredocQueue.length &&
            (stack.context.type !== 'heredoc' ||
                heredocQueue.slice(-1)[0]?.newlinePos !== stack.context.newlinePos) &&
            input.next == 10 /* \n */) {
            break;
        }
        if ((stack.context.nestLevel == 0 && stack.context.atEnd(input)) ||
            input.next < 0 ||
            ((input.next == 36 /* $ */ || input.next == 64) /* @ */ &&
                (isVariableStartChar(input.peek(1)) ||
                    input.peek(1) == 123 /* { */ ||
                    (isSpecialVariableChar(input.peek(1)) &&
                        (stack.context.nestLevel > 0 || input.peek(1) !== stack.context.endDelimiter))))) {
            break;
        }
        if (stack.context.type.startsWith('quoteLike') &&
            stack.context.startDelimiter !== stack.context.endDelimiter &&
            input.next === stack.context.startDelimiter) {
            ++stack.context.nestLevel;
        }
        else if (stack.context.nestLevel > 0 && input.next === stack.context.endDelimiter) {
            --stack.context.nestLevel;
        }
        else if (input.next == 92 /* \\ */) {
            const escaped = scanEscape(input);
            if (escaped) {
                if (content)
                    break;
                else {
                    input.acceptToken(EscapeSequence, escaped);
                    return;
                }
            }
        }
        else if (!content &&
            (input.next == 91 /* [ */ ||
                input.next == 123 /* { */ ||
                (input.next == 45 /* - */ &&
                    input.peek(1) == 62 /* > */ &&
                    (input.peek(2) == 91 /* [ */ || input.peek(2) == 123))) /* { */ &&
            stack.canShift(afterInterpolation)) {
            input.acceptToken(afterInterpolation);
            return;
        }
        else if (!content &&
            input.next == 58 /* : */ &&
            input.peek(1) == 58 &&
            (stack.canShift(packageNamePart) || stack.canShift(afterPackageName))) {
            let pos = 2, ch;
            while (isIdentifierChar((ch = input.peek(pos))))
                ++pos;
            if (ch == 58 && input.peek(pos + 1) == 58)
                input.acceptToken(packageNamePart);
            else
                input.acceptToken(afterPackageName);
            return;
        }
        input.advance();
    }
    if (content)
        input.acceptToken(InterpolatedStringContent);
}, { contextual: true });
// Note that the paired delimiters enabled by the extra_paired_delimiters
// feature are not dealt with by the quote-like tokenizers.
const quoteLikeOperator = new lr.ExternalTokenizer((input, stack) => {
    if (!(stack.context instanceof Context) || !stack.context.type.startsWith('quoteLike'))
        return;
    if (!stack.context.startDelimiter) {
        const haveWhitespace = isWhitespace(input.next);
        let pos = 1;
        let nextChar = input.next;
        while (isWhitespace(nextChar))
            nextChar = input.peek(pos++);
        if (stack.canShift(QuoteLikeStartDelimiter) && nextChar >= 0 && (!haveWhitespace || nextChar !== 35)) {
            input.acceptToken(QuoteLikeStartDelimiter, pos);
            return;
        }
        return;
    }
    if (stack.canShift(QWElement) && isWhitespace(input.next))
        gobbleWhitespace(input);
    if (stack.canShift(QuoteLikeSeparatorDelimiter) &&
        stack.context.startDelimiter === stack.context.endDelimiter &&
        input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeSeparatorDelimiter, 1);
        return;
    }
    else if (stack.canShift(QuoteLikeEndDelimiter) &&
        stack.context.type === 'quoteLike&regex' &&
        stack.context.startDelimiter !== stack.context.endDelimiter &&
        input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeEndDelimiter, 1);
        return;
    }
    if (stack.canShift(QuoteLikeStartDelimiter) &&
        stack.context.type === 'quoteLike&regex' &&
        stack.context.startDelimiter !== stack.context.endDelimiter) {
        let pos = 1;
        let nextChar = input.next;
        while (isWhitespace(nextChar))
            nextChar = input.peek(pos++);
        if (nextChar === stack.context.startDelimiter) {
            input.acceptToken(QuoteLikeStartDelimiter, pos);
            return;
        }
    }
    if (input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeEndDelimiter, 1);
        return;
    }
    if (input.next >= 0) {
        if (stack.canShift(StringContent)) {
            while (input.next >= 0 &&
                (stack.context.nestLevel > 0 ||
                    input.next !== stack.context.endDelimiter ||
                    (input.next === stack.context.endDelimiter && input.peek(-1) == 92))) {
                if (stack.context.startDelimiter !== stack.context.endDelimiter) {
                    if (input.next === stack.context.startDelimiter)
                        ++stack.context.nestLevel;
                    if (input.next === stack.context.endDelimiter)
                        --stack.context.nestLevel;
                }
                input.advance();
            }
            input.acceptToken(StringContent);
            return;
        }
        else if (stack.canShift(QWElement)) {
            while (input.next >= 0 &&
                !isWhitespace(input.next) &&
                (stack.context.nestLevel > 0 ||
                    input.next !== stack.context.endDelimiter ||
                    (input.next === stack.context.endDelimiter && input.peek(-1) == 92))) {
                if (stack.context.startDelimiter !== stack.context.endDelimiter) {
                    if (input.next === stack.context.startDelimiter)
                        ++stack.context.nestLevel;
                    if (input.next === stack.context.endDelimiter)
                        --stack.context.nestLevel;
                }
                input.advance();
            }
            input.acceptToken(QWElement);
            return;
        }
    }
}, { contextual: true });
const regex = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(patternMatchStart)) {
        gobbleWhitespace(input);
        if (input.next == 47 /* / */)
            input.acceptToken(patternMatchStart);
    }
    if (!(stack.context instanceof Context) || !stack.context.type.endsWith('regex'))
        return;
    if (stack.canShift(RegexOptions) &&
        stack.context.quoteLikeType &&
        isRegexOptionChar(input.next, stack.context.quoteLikeType)) {
        while (input.next >= 0 && isRegexOptionChar(input.next, stack.context.quoteLikeType))
            input.advance();
        input.acceptToken(RegexOptions);
        return;
    }
    if (stack.canShift(regexEnd)) {
        input.acceptToken(regexEnd);
        return;
    }
}, { contextual: true });
const pod = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(PodDirective)) {
        if ((input.peek(-1) == 10 /* \n */ || input.peek(-1) < 0) &&
            input.next == 61 /* = */ &&
            isASCIILetter(input.peek(1))) {
            while (input.next >= 0 && input.next != 10)
                input.advance();
            input.acceptToken(PodDirective);
            return;
        }
    }
    if (stack.canShift(PodContent)) {
        while (input.next >= 0) {
            if (input.next != 10) {
                input.advance();
                continue;
            }
            input.advance();
            if (input.peek(0) == 61 /* = */ &&
                input.peek(1) == 99 /* c */ &&
                input.peek(2) == 117 /* u */ &&
                input.peek(3) == 116 /* t */ &&
                (input.peek(4) == 10 || input.peek(4) < 0))
                break;
        }
        input.acceptToken(PodContent);
        return;
    }
    if (stack.canShift(PodCut)) {
        if ((input.peek(-1) == 10 || input.peek(-1) < 0) &&
            input.peek(0) == 61 /* = */ &&
            input.peek(1) == 99 /* c */ &&
            input.peek(2) == 117 /* u */ &&
            input.peek(3) == 116 /* t */ &&
            (input.peek(4) == 10 || input.peek(4) < 0)) {
            input.acceptToken(PodCut, 4);
            return;
        }
    }
});
const endData = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(endDataBlock)) {
        while (input.advance() >= 0)
            ;
        input.acceptToken(endDataBlock);
    }
});

// This file was generated by lezer-generator. You probably shouldn't edit it.
const spec_Identifier = {__proto__:null,q:85, qq:91, __FILE__:121, __LINE__:123, __PACKAGE__:125, __SUB__:127, qw:143, qx:165, m:169, qr:177, s:181, tr:185, y:187, our:209, state:211, my:213, local:215, sub:219, prototype:235, package:241, use:251, no:253, if:261, lib:265, subs:269, feature:273, require:279, constant:283, parent:287, base:289, async:297, return:305, unless:307, while:309, until:311, for:313, foreach:315, elsif:321, else:325, continue:335, BEGIN:353, UNITCHECK:355, CHECK:357, INIT:359, END:361, __END__:371, __DATA__:373, next:377, last:379, redo:381, x:391, lt:405, gt:407, le:409, ge:411, eq:415, ne:417, cmp:421, isa:423, and:435, or:437, xor:439, not:447, fork:455, getpid:457, time:459, times:461, wait:463, wantarray:465, grep:471, map:473, join:475, sort:477, unpack:479, bless:491, print:495, say:497, printf:499, STDIN:501, STDERR:503, STDOUT:505, exec:509, system:511, SUPER:515, eval:873, do:539, goto:543, push:551, unshift:553, splice:555, pop:559, shift:561, each:565, values:567, keys:569};
const parser = lr.LRParser.deserialize({
  version: 14,
  states: "#GvQ`Q!1hOOP(QOpOOO(YQ!LsO'#JWOOQq'#JW'#JWOOO#t'#JY'#JYO+nO!!^O'#DVO,hO! pO'#DXOOO#t'#J]'#J]O,oO!!^O'#DYO,wQ!LsO'#JXOOQ'y'#JX'#JXO0nQ!LsO'#DcO3xQNYO'#DbOOQq'#J_'#J_O3}OpO'#DgOOQ'y'#J`'#J`OOQq'#Ja'#JaOOQq'#Jb'#JbOOQq'#Jc'#JcOOQq'#Jd'#JdOOQq'#Di'#DiO4SQ!LsO'#DiO?[Q#${O'#EfOB_Q!LsO'#J^OB{Q!&bO'#DrOOO#t'#Jh'#JhOH[O!!^O'#DtOOQq'#Je'#JeOHdQNYO'#DwOHoQ!&bO'#DyONOQ!1hO'#EvO!%iQ!&bO'#HQO!%pQ!LsO'#K_O!(uO! pO'#EOOOO#t'#Jj'#JjO!(|O!!^O'#EPOOO#t'#Jk'#JkO!)UO!!^O'#ERO!)^OMhO'#ETOOO#t'#Jl'#JlO!)cO!!^O'#EVOOO#t'#Jm'#JmO!)kO!!^O'#EXOOO#t'#Jo'#JoOOO#t'#Jp'#JpO!)sO!!^O'#EZO!){QNYO'#E^O!*WQNYO'#E`O!*cQNYO'#EbO!*qQNYO'#EdOOQt'#Jr'#JrOOQt'#Js'#JsOOQt'#Jt'#JtOOQt'#Ju'#JuOOQt'#Jq'#JqO!+bQN^O'#EgOOQp'#Jx'#JxOOQp'#J{'#J{O!+iQNYO'#EwOOQp'#J}'#J}OOQp'#KO'#KOO!,SQ$ItO'#E|O!+nQ$ItO'#E|OOQ'x'#KR'#KROOQp'#KW'#KWO!,dQNYO'#F[O!,iQNZO'#K^O!,wQNZO'#FdOOQp'#K`'#K`O!-bQNYO'#ElO!-rQNYO'#FeOOQ'y'#Ka'#KaO!3TQ!&cO'#FiOOQ'x'#Kd'#KdOOQ'x'#Ke'#KeOOQ'x'#Kf'#KfOOQ'x'#Kg'#KgOOQ'x'#Kh'#KhO!3qQNYO'#FhO!4VQNYO'#FpO!4VQNYO'#FuO!4VQNYO'#FvO!4[QNYO'#GOO!4VQNYO'#FzO!4mQ$ItO'#F|O!5UQ!1iO'#GOO!<`QNZO'#GQO!,wQNZO'#GPOOQp'#Kl'#KlOOQp'#Km'#KmOOQp'#Kn'#KnOOQp'#Ko'#KoOOQp'#Kp'#KpO!<kQNYO'#GROOQ3O'#GX'#GXOOQ3O'#GY'#GYO!<pO,UO'#GZOOQ7|'#Kr'#KrOOQ7|'#Ks'#KsO!<uQ!6fO'#G[OOQ3O'#Jz'#JzOOQ'x'#LU'#LUO!<zQ!&bO'#HQO!<zQ!&bO'#HQO!<zQ!&bO'#HUOOQq'#LV'#LVOOQq'#LW'#LWOOQq'#LX'#LXOOQq'#LY'#LYOOQq'#LZ'#LZOOQq'#L['#L[O!=RQ!LsO'#HWO!@gQ#${O'#H_OOQ'x'#L^'#L^OOQ'x'#L_'#L_OOQ'x'#L`'#L`OOQ'x'#La'#LaOOQ'x'#Lb'#LbOOQ'x'#L]'#L]O!C_Q!&bO'#H`O!MtQ!&bO'#H`O#$iQ!&bO'#HgO!C_Q!&bO'#HfOOQq'#Hh'#HhOOQp'#Lc'#LcO#%`QNYO'#HjOOQ'y'#Lf'#LfOOQ'y'#Lg'#LgOOQ'y'#Lh'#LhO#.WQ#${O'#HlOOQ'y'#Ln'#LnOOQ'y'#Lo'#LoO#.nQ#${O'#HsOOQp'#Lq'#LqO#.{QNYO'#HyO#/TQNYO'#HyO!<kQNYO'#H|O!<zQ!&bO'#IOO#/YOMxO'#IPOOQ'y'#IR'#IRO#6lQ#${O'#IQOOQ'y'#Ls'#LsO#>pQ#${O'#ISOOQ'x'#Lt'#LtO#EVQ!&bO'#IUOOQp'#Lv'#LvOOQp'#Lw'#LwOOQp'#Lx'#LxOOQp'#Lu'#LuO#E^QNYO'#IYOOQq'#L{'#L{OOQq'#L|'#L|OOQq'#Lz'#LzO#EiQ!LsO'#I^OOQp'#MP'#MPOOQp'#MQ'#MQOOQp'#MR'#MROOQp'#MO'#MOO#ITQNYO'#IaOOQq'#J^'#J^O#IfQNYO'#D`OOQ3O'#Ix'#IxQ`Q!1hOOO#IqO$fO'#CtO#IyO! pO'#CuPOOO)CDy)CDyO#JQQ!&bO,5:hO$ rQN^O,5>bO$'VQ!&bO,5:iOOOO'#Ih'#IhO$'^OMhO'#JZO$'fO#tO,59qO$'kO#tO,59qO$'pO!$fO'#JWO$)WO!bO'#CyOOQ'y,59s,59sO$)]O! pO,59sO$)dO!$fO'#JVOOO%|'#JV'#JVOOO%|'#If'#IfO$*tO!$fO,59tO$*{O#tO,59tO$ ^QN^O,5>bO$+QQN[O'#IjO$+YQNYO,59}O$+bQN[O,59|OOQ'y,5:R,5:RO!4VQNYO,5>gO!<zQ!&bO,5:YO$+jQN[O'#IpO$+rQ!&cO,5;eOOQp,5<c,5<cO$1[Q!1hO,5?`O$1cQ#${O'#EfO$1sQ!LrO,5@yOB{Q!&bO'#DrO$4cQNYO,5:^O$4hQ!&bO'#DzO!*|QN^O'#EgO$4rQNYO'#ElO$4}O#tO'#DvOOQq,5:`,5:`O$5VO#tO,5:`OOQq,5:c,5:cO#JQQ!&bO,5:cO$5[Q!LrO'#JfO$5fQNYO,5:eO$5kQ!LsO'#JfO$5rQNYO,5:fO$5wQNZO'#KtOOQq'#Ku'#KuOOQq'#Kv'#KvOOQq'#Kw'#KwO$6RQNZO'#G_OOQ3O'#Kt'#KtOOQ3O'#Io'#IoO$6`Q!1hO,5;bOOQ3P,5;b,5;bO$4hQ!&bO,5:fO$8TQ!LsO,5=lO$:VQ!&bO'#KcO!,wQNZO,5<SO!<zQ!&bO,5<}OOQ'x'#Kx'#KxO!<zQ!&bO,5=PO$?cQ!&bO,5=SOOQ'x'#Ky'#KyOOQ'x'#Kz'#KzOOQ'x'#K{'#K{OOQ'x'#K|'#K|O!<zQ!&bO'#IvO$BfQ!LsO,5=SOOQ'x'#K}'#K}OOQ'x'#LO'#LOO!<zQ!&bO'#IwO$CSQ!LsO,5=SOOQ'x'#LP'#LPOOQ'x'#LQ'#LQOOQ'x'#Gx'#GxOOQ'x'#LR'#LROOQ'x'#LS'#LSOOQ'x'#LT'#LTO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SO!<zQ!&bO,5=SOOQq,5=p,5=pO$CpQ!&bO,5>rOOQq,5:j,5:jO$CwO! pO,5:jO$DOO!$fO,5:kO$DYO#tO,5:kO$D_O!$fO,5:mO$DiO#tO,5:mO$DnO! pO,5:oO$DuO!$fO,5:qO$EPO#tO,5:qO$EUO!$fO,5:sO$EcO#tO,5:sO$EhO#tO,5:uO$EmO#tO,5:uOOQq,5:x,5:xO#JQQ!&bO,5:xOOQq,5:z,5:zO#JQQ!&bO,5:zOOQq,5:|,5:|O#JQQ!&bO,5:|O$MVQ#${O,5>RO$MyQ#${O,5>ROOQq,5;O,5;OO#JQQ!&bO,5;OO% OQN^O,5;ROOQq,5;R,5;RO% VQNYO,5<PO% [Q$IuO'#EyO% mQ$IuO,5;cO% {Q(JRO'#EyO%'^Q(JRO,5;hO%,tQ!&bO'#KQO%,{QNYO,5;mOOQp'#KS'#KSO%-TQNYO,5;oOOQp'#KT'#KTO%-fQNYO,5;qOOQq'#KV'#KVO%-qQNZO,5;sO!,wQNZO,5;uOOQp'#KX'#KXO%.UQNYO,5;xOOQq'#KY'#KYOOQq'#KZ'#KZO%.cQ$IuO,5;zO%.vQNZO'#EyO!,wQNZO,5;vOOQ'y'#Jg'#JgO%/RQ!&cO'#IrO%/uQNZO,5@xOOQ3P'#J|'#J|OOQ3O,5<O,5<OO%0TQ0>YO'#EnOOQq'#Er'#ErO%0[QNYO'#EpOOQq'#In'#InO%0dQNYO,5;WOOQq'#Fg'#FgO%0lQNZO,5<PO!<kQNYO,5<mO%0}Q!1hO'#EvOOQq,5;W,5;WO%1_QNYO,5;WO!<kQNYO,5;WO%1gQNYO,5;WO%4UQ!LsO'#K_O%4xQNZO'#KbOOQq,5<T,5<TOB{Q!&bO'#DrO!<kQNYO,5<[O!<kQNYO,5<aO!<kQNYO,5<bO!4VQNYO,5<bO!4VQNYO,5<fO%5jQ$ItO,5<hO%=YQ!1iO,5<jO!<kQNYO,5<fO%=aQ!&cO,5<gO!<kQNYO,5<hO!4VQNYO,5<hO%=kQNYO,5<hO%=pQNYO,5<hOOQp'#Kk'#KkO!<kQNYO'#FxOOQ3O,5<j,5<jO%6RQ!1iO,5<jO%>RQNYO'#ItOOQq-E<r-E<rOOQ3O,5<k,5<kOOQ3O,5<m,5<mO%>WO,UO,5<uOOQ3O,5<v,5<vO%>]Q!LsO,5=lO%@_Q!LsO,5=pO%CpQNYO,5=rOOQq,5=y,5=yO%CuQ!LsO'#KPOOQq'#FQ'#FQOOQq,5=z,5=zO!-wQ!&bO,5>hOOQq,5>Q,5>QO%DuQNYO'#DzOOQq'#Le'#LeOOQq'#Ld'#LdO%E]QNYO'#LdOOQq,5>U,5>UO!<zQ!&bO'#LeO%EdQ#${O'#JWO$1cQ#${O'#EfO%M]Q!&bO'#DrOOQ'y'#Lj'#LjOOQ'y'#Lk'#LkOOQ'y'#Ll'#LlOOQ'y'#Lm'#LmOOQq'#Li'#LiOOQq,5>W,5>WO&$uQ#${O'#LiO&/aQ#${O'#JWO&/qQ!&bO'#DrOOQq'#Lp'#LpO&5QQ#${O'#LpOOQq,5>_,5>_O&5_Q!LsO'#EyO&8vQ!LsO,5>eO&<[QNYO,5>eO&>aQ!LsO,5>jOOQq,5>k,5>kO&?vO`O,5>kOOQq,5>l,5>lOOQq,5>n,5>nO&GfQ#${O,5>pO&JYQ!LsO,5>pO%,{QNYO'#LyO&KiQNYO'#LyOOQq,5>t,5>tOOQq'#L}'#L}O&KqQNYO'#L}OOQq,5>x,5>xOOQq'#MS'#MSO&KyQNYO'#MSOOQq,5>{,5>{OOQq,59z,59zO#JQQ!&bO,59zOOQ3O-E<v-E<vOOO%|,59`,59`O&LXOpO,59`O&L^O! pO,59aOOO%|,59a,59aO&NzQ!LrO1G0SO#JQQ!&bO1G0SO' RQ!&bO1G0TOOQq'#Hx'#HxO' YQ!LsO1G3|O'$nQNYO1G3|O'$sQ#$zO1G0TO''hQ!LrO1G0TOOOO-E<f-E<fO''oO!!^O,5?uO''zO#tO1G/]O'(PO#tO1G/]O'(UOMhO'#IgO'(ZO!bO,59fO'(cOMhO,59mO'(wOMhO,59mO')POMhO,59mO')[OMhO,59kO')vOMhO,59eOOQ'y1G/_1G/_OOO%|-E<d-E<dOOQ'y1G/`1G/`O'){O!$fO1G/`O'){O!$fO1G/`OOQp,5?U,5?UOOQp-E<h-E<hOOQq'#Dd'#DdOOQq1G/h1G/hOOQq1G4R1G4RO'*SQ!LsO1G/tOOQ'y,5?[,5?[OOQ'y-E<n-E<nO$5wQNZO'#IuOOQ3O'#Iu'#IuO'+cQ!1hO1G4zOOQq1G4z1G4zO'+jQ!&cO'#IkO',WQNYO,5@QPOQq1G6e1G6eOOQq1G/x1G/xOOO#t'#Il'#IlO',iO#tO,5:bOOQq,5:b,5:bOOQq1G/z1G/zO',qQ!LrO1G/}OOQq1G0P1G0POOQq1G0Q1G0QOOQ3O,5A`,5A`OOQ3O,5<y,5<yO!,wQNZO,5<yO$5wQNZO,5<yOOQ3O-E<m-E<mOOQ3P1G0|1G0|O',xQNYO1G0QOOQq,5@},5@}OOQ3O1G1n1G1nO',}Q!LsO1G2iO'.^Q!LsO1G2kO'2{Q!LsO1G2nO!<zQ!&bO1G2kO'5]Q!LsO,5?bOOQq-E<t-E<tO'8oQ!LsO,5?cOOQq-E<u-E<uO':OQ!LsO1G2nO'=_Q!LsO1G2nO'=lQ!LsO1G2nO'@{Q!LsO1G2nO'A`Q!LsO1G2nO'ERQ!LsO1G2nO'EYQ!LsO1G2nO'HoQ!LsO1G2nO'HvQ!LsO1G2nO'LSQ!LsO1G2nO'LdQ!LsO1G2nO'LtQ!LsO1G2nO'NTQ!LrO1G4^O!<zQ!&bO1G4^OOQq1G0U1G0UO'N[O#tO1G0VOOQq1G0V1G0VO'NaO!$fO1G0VO'NhO!$fO1G0VO'NrO#tO1G0XO'NwO&jO1G0XO( PO!$fO1G0XO( WO!$fO1G0XO( bO&jO1G0ZO( jO! pO1G0ZO( qO#tO1G0]O( vO&jO1G0]O(!OO!$fO1G0]O(!VO!$fO1G0]OOO%|'#Jn'#JnO(!aO!!^O'#JnO(!iO#tO1G0_O(!qO!$fO1G0_O(!{O!$fO1G0_O(#VO!$fO1G0_O(!iO#tO1G0aO(#dO#tO1G0aO(#iQ!LrO1G0dO(#pQ!LrO1G0fO(#wQ!LrO1G0hO($OQ#${O,5;eO(&mQ!LrO1G0jO0]QNYO'#DcOOQp'#Jw'#JwO(&tQN^O'#JwO('VQNYO'#JvO('bQNYO1G0mO%0lQNZO1G1kO('gQ$IuO,5;eOOQ3O1G0}1G0}O('xQNZO1G0}O((TQ(JRO,5;eOOQ3O1G1S1G1SO!,wQNZO1G1SO%'aQ!&cO1G1SO(-fQ!LrO,5@lOOQp,5@l,5@lO(-pQNYO1G1XO!,wQNZO1G1ZOOQq'#KU'#KUO!,wQNZO1G1]OOQ3O1G1_1G1_O!,wQNZO1G1_OOQ3O1G1a1G1aOOQp'#Ef'#EfO%,{QNYO1G1dO!,wQNZO1G1dOOQq'#K]'#K]O%-TQNYO'#K]O(-zQNZO'#K[O!,wQNZO1G1fO(.YQNYO1G1fOOQ3O1G1b1G1bOOQq,5?^,5?^OOQq-E<p-E<pOOQq,5;Y,5;YO(._QNYO,5;YO(.dQNYO,5:^O(.iQNZO,5;[OOQp'#Jy'#JyO(.zQNYO,5;`OOQq-E<l-E<lO!<kQNYO1G0rO%1gQNYO1G0rO%0dQNYO1G1kOOQ3O1G1k1G1kO(/PQNZO1G1kO('xQNZO1G1kO%1gQNYO1G1kOOQ3O1G2X1G2XO(/_QNYO'#EpO%1_QNYO1G0rOOQq1G0r1G0rO%1gQNYO1G0rO(/dQNZO,5@|O(0UQ!1hO1G1vO(7]Q!1hO1G1{O(>dQ!1hO1G1|O!<kQNYO1G1|O!<kQNYO1G2QO%=aQ!&cO1G2RO!<kQNYO1G2SO!4VQNYO1G2SO(EhQNYO1G2SO(EmQNYO1G2SOOQ3O1G2U1G2UO(FOQ!1iO1G2UO(MVQ!1hO1G2QO)&ZQ!LsO1G2RO!,wQNZO1G2RO)&eQ!1hO1G2SO)-iQNYO1G2SOOQ3P,5<d,5<dOOQ3O1G2a1G2aOOQq1G3^1G3^O)-nQ#${O'#IkO)0zQ!LsO,5@kO)4OQ!LsO'#K^OOQq1G4S1G4SO$4hQ!&bO,5:fP!<zQ!&bO,5BOO)7aQNYO,5BOO)8TQ!LsO,5BPO);RQ!LsO,5@QO)>VQNYO,5:^OB{Q!&bO,5BTOOQq,5BT,5BTOHoQ!&bO,5:hO)>[Q!&bO,5:iOOQq,5B[,5B[O)DRQ#$zO,5B[O)EzQNYO,5:^OB{Q!&bO,5B[OOQq1G4P1G4POOQp'#Hz'#HzO)FPQNYO1G4POOQq1G4V1G4VO!C_Q!&bO,5BeO%,{QNYO,5BeO)FXQNYO,5BiO)F^QNYO,5BnO)FcQ!LrO1G/fOOO%|1G.z1G.zOOO%|1G.{1G.{OOQq7+%n7+%nO)FjQ!LsO'#LdO)IiQ!LrO7+%nO)IpQ#$zO7+%oO)LeQ!LrO7+%oOOQq7+)h7+)hO)LlQNYO7+)hOOQq7+%o7+%oO)LqOMhO'#IiOOO#t'#Ii'#IiO)LyO!!^O1G5aOOQ'y7+$w7+$wO)MUO#tO7+$wO)MZOMjO,5?ROOO!b-E<e-E<eO)McOMhO1G/XO)MhOMhO1G/XO)M|OMhO1G/VO)NhOMhO1G/XO)NpOMhO1G/VO)NuOMhO1G/VO)NzOMjO1G/POOQ'y7+$z7+$zO* SO!$fO7+$zOOQ3O,5?a,5?aOOQ3O-E<s-E<sOOQq7+*f7+*fO* ZQ!LsO,5?VOOQq-E<i-E<iOOO#t-E<j-E<jOOQq1G/|1G/|OOQq7+%i7+%iOOQ3O1G2e1G2eO!,wQNZO1G2eO*!ZQ!LsO7+%lO)0iQNZO,5@kO*({Q!LsO7+(VO!<zQ!&bO7+)xO**[Q!LsO7+)xOOQq7+%q7+%qO*+kO#tO7+%qO*+pO!$fO7+%qO*+wO&jO7+%sOOQq7+%s7+%sO*+zO&jO7+%sO*,PO#tO7+%sO*,UO!$fO7+%sOOQq7+%u7+%uO*,]O&jO7+%uO*,bO&jO7+%uO*,jO&jO7+%wOOQq7+%w7+%wO*,mO&jO7+%wO*,rO#tO7+%wO*,wO!$fO7+%wOOO%|,5@Y,5@YO*-OO#tO,5@YO*-TO!$fO7+%yO*-_O#tO7+%yO*-dO&jO7+%yO*-lO!$fO7+%yO(!iO#tO7+%yO(!{O!$fO7+%yO*-sO#tO7+%{O(!iO#tO7+%{OOQq7+&O7+&OOOQq7+&Q7+&QOOQq7+&S7+&SOOQq7+&U7+&UO*-xQNYO,5@cO*-}QN^O'#ImO*.[QNYO,5@bOOQq7+&X7+&XO%0dQNYO7+'VOOQ3O7+'V7+'VO(/PQNZO7+'VO('xQNZO7+'VO%1gQNYO7+'VOOQ3O7+&i7+&iOOQ3O7+&n7+&nO!,wQNZO7+&nO*.gQ(JRO7+&sOOQ3O7+&u7+&uOOQ3O7+&w7+&wOOQ3O7+&y7+&yO#JQQ!&bO7+'OOOQ3O7+'O7+'OO*.zQNYO,5@wO*/PQNZO'#IqO*/dQNZO,5@vOOQ3O7+'Q7+'QO*/rQNZO7+'QOOQq1G0t1G0tOOQq1G0y1G0yOOQq1G0v1G0vO*0SQ08QO'#EnOOQp1G0z1G0zOOQq7+&^7+&^O%1gQNYO7+&^O!<kQNYO7+&^O(/PQNZO7+'VO%1gQNYO7+'VOOQp'#Ki'#KiO!4VQNYO'#FqOOQ3O'#Is'#IsO*0[Q!1hO7+'bOOQp'#Kj'#KjO!<kQNYO'#FsOOQ3O7+'b7+'bO*7cQ!1hO7+'gOOQ3O7+'g7+'gOOQ3O7+'h7+'hO*>jQ!1hO7+'hO*EnQ!1hO7+'lO)&ZQ!LsO7+'mO!,wQNZO7+'mO*LrQ!1hO7+'nO!<kQNYO7+'nO!4VQNYO7+'nO+%vQNYO7+'nOOQ3O7+'p7+'pOOQ3O7+'l7+'lO#JQQ!&bO7+'mO+%{QNYO7+'mOOQ3O7+'n7+'nO+&QQ#${O'#IrO+(xQ!LsO,5@xO+,ZQNYO1G0QO+,`Q!LsO1G7jOOQq1G7j1G7jO#JQQ!&bO1G7jOOQq1G7o1G7oO+/qQNYO1G7oO+/vQ!LrO1G0SO+0TQ!LrO1G0TO+0bQNYO1G7vOOQq1G7v1G7vO+0gQ!LsO7+)kOOQq1G8P1G8PO$:VQ!&bO1G8POOQq1G8T1G8TOOQq1G8Y1G8YOOQq7+%Q7+%QOOQq<<IY<<IYOOQq<<IZ<<IZO+3{Q!LsO<<MSOOO#t,5?T,5?TOOO#t-E<g-E<gOOQ'y<<Hc<<HcOOO!b1G4m1G4mOOO%|7+$s7+$sO+7aOMhO7+$sO+7fOMhO7+$qO+7kOMhO7+$qO+7pOMhO7+$sO+8UOMhO7+$qOOO%|7+$q7+$qOOO%|'#C}'#C}OOO%|7+$k7+$kOOQ'y<<Hf<<HfOOQ3O7+(P7+(PO+;VQ!LsO1G/xO+;jQ!LsO<<MdOOQq<<I]<<I]OOQq<<I_<<I_O+<yO&jO<<I_O+=OO&jO<<I_OOQq<<Ia<<IaO+=WO&jO<<IaOOQq<<Ic<<IcO+=]O&jO<<IcO+=bO&jO<<IcOOO%|1G5t1G5tO+=jO#tO<<IeO+=oO&jO<<IeO+=wO!$fO<<IeOOQq<<Ie<<IeO+=rO&jO<<IeO+>OO!$fO<<IeO+>YO#tO<<IgO+>_O#tO<<IgOOQp1G5}1G5}OOQp,5?X,5?XOOQp-E<k-E<kO('xQNZO<<JqO%1gQNYO<<JqO(/PQNZO<<JqOOQ3O<<Jq<<JqO%1gQNYO<<JqOOQ3O<<JY<<JYOOQ3O<<J_<<J_O!,wQNZO<<J_O%'aQ!&cO<<J_O+>dQ!&cO<<J_O+>tQ!LsO<<JjOOQq1G6c1G6cOOQq,5?],5?]OOQq-E<o-E<oO!,wQNZO<<JlO!<kQNYO<<IxOOQq<<Ix<<IxO!<kQNYO,5<]OOQ3O-E<q-E<qOOQ3O<<J|<<J|OOQ3O,5<_,5<_OOQ3O<<KR<<KROOQ3O<<KS<<KSOOQ3O<<KW<<KWO#JQQ!&bO<<KXO+?OQNYO<<KXOOQ3O<<KY<<KYO+?TQ!1hO<<KYO!<kQNYO<<KYO!4VQNYO<<KYO+>tQ!LsO<<KXO!<kQNYO<<KXOOQq7+%l7+%lO+FXQ!LrO7+-UOOQq7+-Z7+-ZOOQq7+-b7+-bOOQq<<MV<<MVO+F`QNYO7+-kO+FeQ!LsO1G/xO+IdQ!LsO1G/xOOQqANBnANBnOOO%|<<H_<<H_OOO%|<<H]<<H]O+LcOMhO<<H]O+LhOMhO<<H_O+LmOMhO<<H]OOQqAN>yAN>yO+LrO&jOAN>yOOQqAN>{AN>{OOQqAN>}AN>}O+LwO&jOAN>}O+L|O&jOAN?POOQqAN?PAN?PO+MPO&jOAN?PO+MUO#tOAN?PO+MZO!$fOAN?PO+MbO&jOAN?RO+MjO#tOAN?ROOQ3OAN@]AN@]O%1gQNYOAN@]O('xQNZOAN@]OOQ3OAN?yAN?yO!,wQNZOAN?yO%'aQ!&cOAN?yOOQ3OAN@UAN@UOOQ3OAN@WAN@WOOQqAN?dAN?dOOQ3O1G1w1G1wO+>tQ!LsOAN@sO!<kQNYOAN@sOOQ3OAN@tAN@tO+MoQ!1hOAN@tO!<kQNYOAN@tO#JQQ!&bOAN@sOOQ3OAN@sAN@sOOQq<=!p<=!pOOQq<=#V<=#VOOO%|AN=wAN=wOOO%|AN=yAN=yO,&sOMhOAN=wOOQqG24eG24eOOQqG24iG24iOOQqG24kG24kO,&xO&jOG24kO,&}O&jOG24kOOQqG24mG24mO,'VO&jOG24mO,'[O&jOG24mO('xQNZOG25wOOQ3OG25wG25wOOQ3OG25eG25eO!,wQNZOG25eO#JQQ!&bOG26_OOQ3OG26_G26_OOQ3OG26`G26`O,'dQ!1hOG26`O,.hQ!LrOG26_OOO%|G23cG23cOOQqLD*VLD*VO,.oO&jOLD*VOOQqLD*XLD*XO,.tO&jOLD*XOOQ3OLD+cLD+cOOQ3OLD+PLD+PO,.yQ!LrOLD+yOOQ3OLD+zLD+zO!<kQNYOLD+yOOQq!$'Mq!$'MqOOQq!$'Ms!$'MsO!<kQNYO!$( eOOQ3O!$( e!$( eOOQ3O!)9EP!)9EPO,/QQNYO'#E^O#%`QNYO'#HjO#JQQ!&bO'#IOO,/]Q#${O'#IQO,0PQ#${O'#ISO,0sQ!&bO'#IUO,0zQNYO'#D`O#JQQ!&bO'#HQO#JQQ!&bO,5:YO,1VQ#${O'#EfO,4ZQ!LsO'#JfO#JQQ!&bO,5<}O#JQQ!&bO,5=PO,5QQ!&bO,5=SO#JQQ!&bO'#IvO,7hQ!LsO,5=SO#JQQ!&bO'#IwO,8UQ!LsO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO#JQQ!&bO,5=SO,8rQ!LsO'#K_O,>aQ!LsO,5=lO,?QQ!LsO'#KPO,?eQ#$zO'#JWO,G_Q#${O'#JWO,IvQ#${O'#JWO,LOQ!LsO,5>jO,L{Q#${O,5>pO- YQ!LsO,5>pO-!PQ#$zO1G0TO-$wQ!LsO1G/tO-%hQ!LsO1G2iO-&XQ!LsO1G2kO-)nQ!LsO1G2nO#JQQ!&bO1G2kO-)uQ!LsO,5?bO-*iQ!LsO,5?cO-+`Q!LsO1G2nO-.VQ!LsO1G2nO-.dQ!LsO1G2nO-1ZQ!LsO1G2nO-1nQ!LsO1G2nO-4wQ!LsO1G2nO-5OQ!LsO1G2nO-7{Q!LsO1G2nO-8SQ!LsO1G2nO-:vQ!LsO1G2nO-;WQ!LsO1G2nO-;hQ!LsO1G2nO#JQQ!&bO1G4^O-<XQNYO,5:^O#JQQ!&bO,5BOO-<^Q!LrO,5BPO-<kQNYO,5:^O-<pQNYO,5:^O-<uQ!LsO7+(VO#JQQ!&bO7+)xO-=fQ!LsO7+)xO->]Q!LrO1G/xO->gQ!LsO1G/xO-AfQ!LsO<<MdO-B]Q!LsO'#J^O-GmQ!&bO'#HQO#JQQ!&bO'#HQO#JQQ!&bO'#HUO-L}Q#${O'#H_O.)VQ#${O'#HlO.)mQ#${O'#HsO.)zQ!&bO,5>rOB{Q!&bO'#DrO!<zQ!&bO'#LeO%M]Q!&bO'#DrO&/qQ!&bO'#DrO.*RQ!LrO1G4^O.*YQ!&bO,5BeO.*aQNYO,5:^O.*fQNYO,5:^O.*YQ!&bO'#H`O./tQ!&bO'#H`O.*YQ!&bO'#HfO%,{QNYO'#LyOB{Q!&bO'#DrOB{Q!&bO'#DrO./{QNYO'#IY",
  stateData: ".0v~OgOS'xOS'oPQ'pPQ~OQ]OR#dOS#kOT#}OU$OOd#SOjQOkROlROpfOwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO#l!ZO#o#RO#q!]O#r!^O#v!aO$P!bO$Y!fO$^!iO$_!kO$`!lO$a!mO$b!nO$c!oO$v!zO$w!{O$x!|O$y!}O$z#OO%P#TO%Q#UO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO)e#QO*f$PO~O'o$iO'p$jO~Ov$mOw$nO!O$lOo'zX!Q'zX!['zX!c'zX!g'zX!o'zX!x'zX#T'zX#V'zX#X'zX#o'zX#v'zX$_'zX$`'zX$a'zX$b'zX$c'zX%W'zX%Y'zX%Z'zX%]'zX%^'zX%_'zX%`'zX%a'zX%b'zX%c'zX%d'zX%e'zX%f'zX%g'zX%h'zX%i'zX%j'zX%k'zX%m'zX%n'zX%o'zX%p'zX%q'zX%r'zX%s'zX%y'zX&{'zX'n'zX!d'zXr'zXt'zX#e'zX~O^$qO'x$oO~OQ$xO[$xO]$xOj$sOkROlRO!T4xO#R4rO'o$iO'p$jO~O(O$uO~P+vO^$zO'x$oO~Ov$|Ov'{Xw'{X!O'{X!Q'{X!['{X!c'{X!g'{X!o'{X!x'{X#T'{X#V'{X#X'{X#o'{X#v'{X$_'{X$`'{X$a'{X$b'{X$c'{X%W'{X%Y'{X%Z'{X%]'{X%^'{X%_'{X%`'{X%a'{X%b'{X%c'{X%d'{X%e'{X%f'{X%g'{X%h'{X%i'{X%j'{X%k'{X%m'{X%n'{X%o'{X%p'{X%q'{X%r'{X%s'{X%y'{X&{'{X'n'{X!d'{Xr'{Xt'{X#e'{X~Oo$}Oo!VX!c(RX!g(RX!d(RX~Ov(RXw(RX!O(RX!Q(RX![(RX!o(RX!x(RX#T(RX#V(RX#X(RX#o(RX#v(RX$_(RX$`(RX$a(RX$b(RX$c(RX%W(RX%Y(RX%Z(RX%](RX%^(RX%_(RX%`(RX%a(RX%b(RX%c(RX%d(RX%e(RX%f(RX%g(RX%h(RX%i(RX%j(RX%k(RX%m(RX%n(RX%o(RX%p(RX%q(RX%r(RX%s(RX%y(RX&{(RX'n(RXr(RXt(RX#e(RX~P0]Oo%PO~OY%QO~Ov%ROw!]X!O!]X!Q!]X![!]X!c!]X!g!]X!o!]X!x!]X#T!]X#V!]X#X!]X#o!]X#v!]X$_!]X$`!]X$a!]X$b!]X$c!]X%W!]X%Y!]X%Z!]X%]!]X%^!]X%_!]X%`!]X%a!]X%b!]X%c!]X%d!]X%e!]X%f!]X%g!]X%h!]X%i!]X%j!]X%k!]X%m!]X%n!]X%o!]X%p!]X%q!]X%r!]X%s!]X%y!]X&{!]X'n!]X!d!]Xr!]Xt!]X#e!]X~Oo%TOv$|O!c%SOQ&ZXR&ZXS&ZXT&ZXU&ZXj&nXk&ZXl&ZXp&nXx&ZXz&ZX}&ZX!O#YX!P&ZX!Q#YX!R&ZX!T&ZX!X&ZX!Y&ZX![#YX!^&ZX!_&ZX!`&ZX!a&ZX!e&ZX!g#YX!i&ZX!l&ZX!o#YX!t&ZX!v&ZX!x#YX!z&ZX!|&ZX#O&ZX#P&ZX#R&ZX#T#YX#V#YX#X#YX#[&ZX#]&ZX#^&ZX#_&ZX#a&ZX#o#YX#v#YX$_#YX$`#YX$a#YX$b#YX$c#YX%W#YX%Y#YX%Z#YX%]#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%m#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%u&ZX%v&ZX%w&ZX%y#YX%{&ZX%|&ZX%}&ZX&O&ZX&P&ZX&Q&ZX&T&ZX&U&ZX&V&ZX&W&ZX&X&ZX&_&ZX&a&ZX&b&ZX&c&ZX&h&ZX&i&ZX&k&ZX&w&ZX&y&ZX&{#YX&}&ZX'O&ZX'P&ZX'R&ZX'S&ZX'U&ZX'V&ZX'W&ZX'n#YX't&ZX(O&ZX(]&ZX*f&ZXt#YX~Ow%WO#e%VO~P7eOv(QXw(QX!O(QX!Q(QX![(QX!o(QX!x(QX#T(QX#V(QX#X(QX#o(QX%W(QX%Y(QX%Z(QX%](QX%^(QX%_(QX%`(QX%a(QX%b(QX%c(QX%d(QX%e(QX%f(QX%g(QX%h(QX%i(QX%j(QX%k(QX%m(QX%n(QX%o(QX%p(QX%q(QX%r(QX%s(QX%y(QX&{(QX'n(QX!d(QXr(QXt(QX#e(QX~O!c%SO!g(QX#v(QX$_(QX$`(QX$a(QX$b(QX$c(QX~P?fOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO!d(YP~O^%`O'x$oO~Oj%cOp%cOw%dO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$POr(YP~O%S%jO%T%kO%U%lOt(YP~P`OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~Ow%rO~PN`Ov$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O#v!aO$_!kO$`!lO$a!mO$b!nO$c!oO%W%vO%Y%xO%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%f&SO%g&QO%h&RO%i&`O%j&UO%k&VO%m&cO%n&dO%o&eO%p&fO%q&XO%r&YO%s&ZO%y&iO&{&jO!c)RX!g)RX#o)RX'n)RX~O(]&kO~P+vO^&mO'x$oO~O^&oO'x$oO~O!x&qO~O^&rO'x$oO~O^&tO'x$oO~O^&vO'x$oO~Oj&xOw&yO!T$fO~Oj&zOw&{O!T$fO~Oj&|Op'OOw&}O!T$fO~Oj'QOw'RO!T$fO~OQ]OjROkROlRO!X'TO!e'SO~O#a!YO~P!*|Op'VO~Op'XO#n'cO#s'YO#v!aO#z'_O#|'aO~O#x']O$R'dO$T'fO$U'gO~P!+nOp'iO~O!c'kO!g'kO#o)QX'n)QX~O#o'nO'n'nO~O$v!zO$w!{O$x!|O$y!}O$z#OO~Op'uOw'xO!e'pO#e'rO~P!-PO#a!YO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~O#v)UP$_)UP$`)UP$a)UP$b)UP$c)UP#o)UP'n)UP~P!-wO#v!aO$_!kO$`!lO$a!mO$b!nO$c!oO~O!e(QO~Ow'xO$`!lO$a!mO$b!nO$c!oO~Oj(]O!e(ZO#[!SO#]!TO#^!UO#_!VO$q(_O~O#o'nO$m(`O'n'nOQ$rXR$rXS$rXT$rXU$rXd$rXj$rXk$rXl$rXp$rXw$rXx$rXz$rX}$rX!O$rX!P$rX!Q$rX!R$rX!T$rX!X$rX!Y$rX![$rX!^$rX!_$rX!`$rX!a$rX!e$rX!i$rX!l$rX!o$rX!t$rX!v$rX!z$rX!|$rX#O$rX#P$rX#R$rX#T$rX#V$rX#X$rX#[$rX#]$rX#^$rX#_$rX#a$rX#l$rX#o$rX#q$rX#r$rX#v$rX$P$rX$Y$rX$^$rX$_$rX$`$rX$a$rX$b$rX$c$rX$v$rX$w$rX$x$rX$y$rX$z$rX%P$rX%Q$rX%u$rX%v$rX%w$rX%y$rX%{$rX%|$rX%}$rX&O$rX&P$rX&Q$rX&T$rX&U$rX&V$rX&W$rX&X$rX&_$rX&a$rX&b$rX&c$rX&h$rX&i$rX&k$rX&w$rX&y$rX&}$rX'O$rX'P$rX'R$rX'S$rX'U$rX'V$rX'W$rX'm$rX't$rX(O$rX(]$rX)e$rX*f$rXt$rX%S$rX%T$rX%U$rX~Op(dO#o$tX'n$tX~Ow'xO~Oe(hO~O'v(iO~Ow%]O~PN`O!e(lOv%zXw%zX!O%zX!Q%zX![%zX!c%zX!g%zX!o%zX!x%zX#T%zX#V%zX#X%zX#o%zX#v%zX$_%zX$`%zX$a%zX$b%zX$c%zX%W%zX%Y%zX%Z%zX%]%zX%^%zX%_%zX%`%zX%a%zX%b%zX%c%zX%d%zX%e%zX%f%zX%g%zX%h%zX%i%zX%j%zX%k%zX%m%zX%n%zX%o%zX%p%zX%q%zX%r%zX%s%zX%y%zX&{%zX'n%zX!d%zXr%zXt%zX#e%zX~Ov&RX!c&RX!g&RX!x&RX#o&RX#v&RX$_&RX$`&RX$a&RX$b&RX$c&RX%W&RX%Y&RX%Z&RX%]&RX%^&RX%_&RX%`&RX%a&RX%b&RX%c&RX%d&RX%e&RX%f&RX%g&RX%h&RX%i&RX%j&RX%k&RX%m&RX%n&RX%o&RX%p&RX%q&RX%r&RX%s&RX&{&RX'n&RX!d&RXr&RXt&RX#e&RX~P!-wOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e(QO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e(QO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~OwnO~P!HkOv$|OQ&ZXR&ZXS&ZXT&ZXU&ZXk&ZXl&ZXx&ZXz&ZX}&ZX!P&ZX!R&ZX!T&ZX!X&ZX!Y&ZX!^&ZX!_&ZX!`&ZX!a&ZX!e&ZX!i&ZX!l&ZX!t&ZX!v&ZX!z&ZX!|&ZX#O&ZX#P&ZX#R&ZX#[&ZX#]&ZX#^&ZX#_&ZX#a&ZX%u&ZX%v&ZX%w&ZX%{&ZX%|&ZX%}&ZX&O&ZX&P&ZX&Q&ZX&T&ZX&U&ZX&V&ZX&W&ZX&X&ZX&_&ZX&a&ZX&b&ZX&c&ZX&h&ZX&i&ZX&k&ZX&w&ZX&y&ZX&}&ZX'O&ZX'P&ZX'R&ZX'S&ZX'U&ZX'V&ZX'W&ZX't&ZX(O&ZX(]&ZX*f&ZX~Oj&ZXp&ZXw&ZX!O&ZX!Q&ZX![&ZX!o&ZX#T&ZX#V&ZX#X&ZX%y&ZX~P!M{Oj(tOw%]O!OmO!e(vO!o(sO#a!YO%v(xO~OQ]OR#dOS#kOT#}OU$OOkROlROwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$POv(YPw(YP!O(YP!Q(YP!c(YP!g(YP!o(YP!x(YP#T(YP#V(YP#X(YP#o(YP#v(YP$_(YP$`(YP$a(YP$b(YP$c(YP%W(YP%Y(YP%Z(YP%](YP%^(YP%_(YP%`(YP%a(YP%b(YP%c(YP%d(YP%e(YP%f(YP%g(YP%h(YP%i(YP%j(YP%k(YP%m(YP%n(YP%o(YP%p(YP%q(YP%r(YP%s(YP%y(YP&{(YP'n(YP!d(YPr(YPt(YP#e(YP~Oj(yOp(zO!e({O&d(|O&e(}O&f)OO~P#%wOj)TOp%XO!e)UO~P#%wOj)ZOp)YO~Oo)[O~OV)_OW)_OX)^Oj)_Op)_O&d(|O&e(}O&f)OO~OQ]OU$OOjQOkROlROwnOxXOzSO}VO!OmO!P$eO!R$eO!T$fO!X$eO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%w#XO%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$POv&tX!x&tX#o&tX%W&tX%Y&tX%Z&tX%]&tX%^&tX%_&tX%`&tX%a&tX%b&tX%c&tX%d&tX%e&tX%f&tX%g&tX%h&tX%i&tX%j&tX%k&tX%m&tX%n&tX%o&tX%p&tX%q&tX%r&tX%s&tX&{&tX'n&tX!d&tXr&tXt&tX#e&tX~OR#dOS#kOT#}Op%XO!Q#YO!YgO!ooO%u#YO%v#YO%y#[O!c&tX!g&tX#v&tX$_&tX$`&tX$a&tX$b&tX$c&tX~P#/tOQ]OU$OOjQOkROlROwnOxXOzSO}VO!OmO!P$eO!R$eO!T$fO!X$eO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%w#XO%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$POv&vX!x&vX#o&vX%W&vX%Y&vX%Z&vX%]&vX%^&vX%_&vX%`&vX%a&vX%b&vX%c&vX%d&vX%e&vX%f&vX%g&vX%h&vX%i&vX%j&vX%k&vX%m&vX%n&vX%o&vX%p&vX%q&vX%r&vX%s&vX&{&vX'n&vX!d&vXr&vXt&vX#e&vX~OR#dOS#kOT#}Op%XO!Q#YO!YgO!ooO%u#YO%v#YO%y#[O!c&vX!g&vX#v&vX$_&vX$`&vX$a&vX$b&vX$c&vX~P#7xOQ]OR#dOS#kOT#}OU$OOjQOkROlROw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~Op)bO~P#?|Ok)dO!e)eO#R!OO~Ok)gO!e)hO#R!OOv'QXw'QX!O'QX!Q'QX!['QX!c'QX!g'QX!o'QX!x'QX#T'QX#V'QX#X'QX#o'QX#v'QX$_'QX$`'QX$a'QX$b'QX$c'QX%W'QX%Y'QX%Z'QX%]'QX%^'QX%_'QX%`'QX%a'QX%b'QX%c'QX%d'QX%e'QX%f'QX%g'QX%h'QX%i'QX%j'QX%k'QX%m'QX%n'QX%o'QX%p'QX%q'QX%r'QX%s'QX%y'QX&{'QX'n'QX!d'QXr'QXt'QX#e'QX~Ok)jOl)jO!e)kO#R!OO#T!PO~Oj)mOw)nO!T$fO~OZ)pOa)qO~OZ)sO~P+vOQ]OR6bOS6nOT4tOU$OOjQOkROlROp4{Ow%]OxXOzSO}VO!OmO!P$eO!Q4yO!R$eO!T$fO!X$eO!Y6^O![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6_O!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u4yO%v4yO%w#XO%y6aO%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~OQ)xOj)xOp)wO!T$fO!e(QO&k#yO~Ow)vO!O)uO~P$ ^OQ]OR6bOS6nOT4tOU$OOjQOkROlROw%]OxXOzSO}VO!OmO!P$eO!Q4yO!R$eO!T$fO!X$eO!Y6^O![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6_O!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u4yO%v4yO%w#XO%y6aO%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~Op)zO~P$ |Og)}O'x$oO~Oa*OO~O^*PO~Ov*TOw*SO!O*VO'q*UO'r*QOQ'zX['zX]'zXj'zXk'zXl'zX!T'zX#R'zX'o'zX'p'zX'snX(O'zX(]'zXZ'zX`'zX!x'zX_'zX~O's*WO~O(O*XO~P+vOv*TOw*SO!O*VO'q*UOQ'yX['yX]'yXj'yXk'yXl'yX!T'yX#R'yX'o'yX'p'yX(O'yX(]'yXZ'yX`'yX!x'yX_'yX~O`*ZO~P+vO^*]O~OP*^Op*^O~Oo$}Oo!Va~OP*`Op*`O~OP*dOp*dO~Oo%TOQ#maR#maS#maT#maU#maj#mak#mal#map#mav#maw#max#maz#ma}#ma!O#ma!P#ma!Q#ma!R#ma!T#ma!X#ma!Y#ma![#ma!^#ma!_#ma!`#ma!a#ma!e#ma!i#ma!l#ma!o#ma!t#ma!v#ma!z#ma!|#ma#O#ma#P#ma#R#ma#T#ma#V#ma#X#ma#[#ma#]#ma#^#ma#_#ma#a#ma%u#ma%v#ma%w#ma%y#ma%{#ma%|#ma%}#ma&O#ma&P#ma&Q#ma&T#ma&U#ma&V#ma&W#ma&X#ma&_#ma&a#ma&b#ma&c#ma&h#ma&i#ma&k#ma&w#ma&y#ma&}#ma'O#ma'P#ma'R#ma'S#ma'U#ma'V#ma'W#ma't#ma(O#ma(]#ma*f#ma#o#ma'n#ma~Ot*iO~P`Ow&qX!d#YXr#YX#e#YX~P7eOv$mOw$nO!O$lO!Q&^O![&_O!c'kO!g'kO!o&^O!x&]O#T&]O#V&WO#X&]O%W%vO%Y%xO%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%f&SO%g&QO%h&RO%i&`O%j&UO%k&VO%m&cO%n&dO%o&eO%p&fO%q&XO%r&YO%s&ZO%y&iO&{&jO!d(YX~O!d*mO~Ow%]Ot(YP~PN`Ow'xO!e'pO#e'rO~O`*pOb*nO~O^%`O~Or(YXt(YX~P$1sOr*sO~Ot(YX~P!%pOt*tO~O#o'nO'n'nO~P!3qOp*xO#o'nO'n'nO~P!3qOt*zO%S%jO%T%kO%U%lO~P`Ov$mOw$nO!O$lO%y&iO!c%ta!g%ta#o%ta#v%ta$_%ta$`%ta$a%ta$b%ta$c%ta%q%ta%r%ta%s%ta'n%ta!d%tar%tat%ta#e%ta~O!Q%ta![%ta!o%ta!x%ta#T%ta#V%ta#X%ta%W%ta%Y%ta%Z%ta%]%ta%^%ta%_%ta%`%ta%a%ta%b%ta%c%ta%d%ta%e%ta%f%ta%g%ta%h%ta%i%ta%j%ta%k%ta%m%ta%n%ta%o%ta%p%ta&{%ta~P$6pOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e6fO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~Ow%]O%W+RO~PN`Ov%[aw%[a!O%[a!Q%[a![%[a!c%[a!g%[a!o%[a!x%[a#T%[a#V%[a#X%[a#o%[a#v%[a$_%[a$`%[a$a%[a$b%[a$c%[a%W%[a%Y%[a%Z%[a%]%[a%^%[a%_%[a%`%[a%i%[a%j%[a%k%[a%m%[a%n%[a%o%[a%p%[a%q%[a%r%[a%s%[a%y%[a&{%[a'n%[a!d%[ar%[at%[a#e%[a~O%a&OO%b%zO%c%{O%d%|O%e%}O%f%[a%g%[a%h%[a~P$?mO%f&SO%g&QO%h&RO%a%[a%b%[a%c%[a%d%[a%e%[a~P$?mO#e+eO~P#JQO(]+fO~P+vO`+hOa+gO~P+vO^+jO~O`+lOa+kO~P+vO^+nO~O!x+oO~P+vO`+rOa+qO~P+vO^+tO~O_+uO`+vOa+wO~P+vO^+zO~Oa+{O~O^+|O~OQ&ZaR&ZaS&ZaT&ZaU&Zaj&Zak&Zal&Zap&Zav&]ax&Zaz&Za}&Za!P&Za!R&Za!T&Za!X&Za!Y&Za!^&Za!_&Za!`&Za!a&Za!c&]a!e&Za!g&]a!i&Za!l&Za!t&Za!v&Za!x&]a!z&Za!|&Za#O&Za#P&Za#R&Za#[&Za#]&Za#^&Za#_&Za#a&Za#o&]a#v&]a$_&]a$`&]a$a&]a$b&]a$c&]a%W&]a%Y&]a%Z&]a%]&]a%^&]a%_&]a%`&]a%a&]a%b&]a%c&]a%d&]a%e&]a%f&]a%g&]a%h&]a%i&]a%j&]a%k&]a%m&]a%n&]a%o&]a%p&]a%q&]a%r&]a%s&]a%u&Za%v&Za%w&Za%{&Za%|&Za%}&Za&O&Za&P&Za&Q&Za&T&Za&U&Za&V&Za&W&Za&X&Za&_&Za&a&Za&b&Za&c&Za&h&Za&i&Za&k&Za&w&Za&y&Za&{&]a&}&Za'O&Za'P&Za'R&Za'S&Za'U&Za'V&Za'W&Za'n&]a't&Za(O&Za(]&Za*f&Za!d&]ar&]at&]a#e&]a~Oo%TOw&]a!O&]a!Q&]a![&]a!o&]a#T&]a#V&]a#X&]a%y&]a~P$ErOw&Za!O&Za!Q&Za![&Za!o&Za#T&Za#V&Za#X&Za%y&Za~P$ErOQ]OjROkROlRO!X,TO!e,UO~O!d(jP~P$NjOp'uO~Oo%TOw#mX#n#mX#o#mX'n#mX~Ow'xO#n,[O#o'nO'n'nO~OQ#mXR#mXS#mXT#mXU#mXj#mXk#mXl#mXp#mXx#mXz#mX}#mX!O#mX!P#mX!Q#mX!R#mX!T#mX!X#mX!Y#mX![#mX!^#mX!_#mX!`#mX!a#mX!e#mX!i#mX!l#mX!o#mX!t#mX!v#mX!z#mX!|#mX#O#mX#P#mX#R#mX#T#mX#V#mX#X#mX#[#mX#]#mX#^#mX#_#mX#a#mX%u#mX%v#mX%w#mX%y#mX%{#mX%|#mX%}#mX&O#mX&P#mX&Q#mX&T#mX&U#mX&V#mX&W#mX&X#mX&_#mX&a#mX&b#mX&c#mX&h#mX&i#mX&k#mX&w#mX&y#mX&}#mX'O#mX'P#mX'R#mX'S#mX'U#mX'V#mX'W#mX't#mX(O#mX(]#mX*f#mX!c#mX!g#mX~P% [O#n,`O#o'nO'n'nO~P$:VOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~O!e6sO~P%'kO!c'kO!g'kO~OxYOzSO}VO![^O(OUO~Ok,eO!e%ZO!iiO~Ok,eO!e%ZO!iiO#o'nO'n'nO~P%-TOp,jOw%]O!o(sO~P%-TO!e,nO!iiO$V,qO#o)OP'n)OP~P%-TOo%TO#o#mX'n#mX~O!c'fX!g'fX#o'fX'n'fX#v'fX$_'fX$`'fX$a'fX$b'fX$c'fX~P!-wO!c'kO!g'kO#o)Qa'n)Qa~O#c,vO~PB{Op,xO#i,yO~O!e(QO#e'rO~Ow'xO!e'pO#e'rO#o'nO'n'nO~Ot%qO%S%jO%T%kO%U%lO~P`Ow'xO#e-UO~O!e(QO#e-UO~Ov$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%W%vO%Y%xO%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%f&SO%g&QO%h&RO%i&`O%j&UO%k&VO%m&cO%n&dO%o&eO%p&fO%q&XO%r&YO%s&ZO%y&iO&{&jO~O!c)RX!g)RX#v)RX$_)RX$`)RX$a)RX$b)RX$c)RX#o)RX'n)RX~P%1oO!c'kO!g'kO#v)UX$_)UX$`)UX$a)UX$b)UX$c)UX#o)UX'n)UX~Oj-bO!e-`O#[!SO#]!TO#^!UO#_!VO$q-dO~O#o'nO'n'nOQ$raR$raS$raT$raU$rad$raj$rak$ral$rap$raw$rax$raz$ra}$ra!O$ra!P$ra!Q$ra!R$ra!T$ra!X$ra!Y$ra![$ra!^$ra!_$ra!`$ra!a$ra!e$ra!i$ra!l$ra!o$ra!t$ra!v$ra!z$ra!|$ra#O$ra#P$ra#R$ra#T$ra#V$ra#X$ra#[$ra#]$ra#^$ra#_$ra#a$ra#l$ra#o$ra#q$ra#r$ra#v$ra$P$ra$Y$ra$^$ra$_$ra$`$ra$a$ra$b$ra$c$ra$v$ra$w$ra$x$ra$y$ra$z$ra%P$ra%Q$ra%u$ra%v$ra%w$ra%y$ra%{$ra%|$ra%}$ra&O$ra&P$ra&Q$ra&T$ra&U$ra&V$ra&W$ra&X$ra&_$ra&a$ra&b$ra&c$ra&h$ra&i$ra&k$ra&w$ra&y$ra&}$ra'O$ra'P$ra'R$ra'S$ra'U$ra'V$ra'W$ra'm$ra't$ra(O$ra(]$ra)e$ra*f$rat$ra%S$ra%T$ra%U$ra~O$m(`O~P%6RO#o'nO'n'nO~PB{Oj-bO~Ol-bO#[!SO#]!TO#^!UO#_!VO~Ow%WO~Of-mO~O!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%W%vO%Y%xO%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%f&SO%g&QO%h&RO%i&`O%j&UO%k&VO%m&cO%n&dO%o&eO%p&fO&{&jO~P$6pOv$mOw$nO!O$lO!Q%xa![%xa!c%xa!g%xa!o%xa!x%xa#T%xa#V%xa#X%xa#o%xa#v%xa$_%xa$`%xa$a%xa$b%xa$c%xa%W%xa%Y%xa%Z%xa%]%xa%^%xa%_%xa%`%xa%a%xa%b%xa%c%xa%d%xa%e%xa%f%xa%g%xa%h%xa%i%xa%j%xa%k%xa%m%xa%n%xa%o%xa%p%xa%q%xa%r%xa%s%xa%y%xa&{%xa'n%xa!d%xar%xat%xa#e%xa~O!d-nO~O!c'kO!g'kO#o(sX#v(sX$_(sX$`(sX$a(sX$b(sX$c(sX'n(sX!d(sXr(sXt(sX#e(sX~P%1oOw-sO~Oj(tOw%]O!OmO!o(sO#a!YO~O%v6gO~P%DzOQ*aXR*aXS*aXT*aXU*aXj*aXk*aXl*aXp*aXx*aXz*aX}*aX!P*aX!Q*aX!R*aX!T*aX!X*aX!Y*aX![*aX!^*aX!_*aX!`*aX!a*aX!c*aX!e*aX!g*aX!i*aX!l*aX!o*aX!t*aX!v*aX!x*aX!z*aX!|*aX#O*aX#P*aX#R*aX#T*aX#V*aX#X*aX#[*aX#]*aX#^*aX#_*aX#a*aX#o*aX#v*aX$_*aX$`*aX$a*aX$b*aX$c*aX%W*aX%Y*aX%Z*aX%]*aX%^*aX%_*aX%`*aX%a*aX%b*aX%c*aX%d*aX%e*aX%f*aX%g*aX%h*aX%i*aX%j*aX%k*aX%m*aX%n*aX%o*aX%p*aX%q*aX%r*aX%s*aX%u*aX%v*aX%w*aX%y*aX%{*aX%|*aX%}*aX&O*aX&P*aX&Q*aX&T*aX&U*aX&V*aX&W*aX&X*aX&_*aX&a*aX&b*aX&c*aX&h*aX&i*aX&k*aX&w*aX&y*aX&{*aX&}*aX'O*aX'P*aX'R*aX'S*aX'U*aX'V*aX'W*aX'n*aX't*aX(O*aX(]*aX*f*aX!d*aXr*aXt*aX#e*aX~P(YOQ]OR#dOS#kOT#}OU$OOj5fOkROlROp(zOwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&d(|O&e(}O&f)OO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO!d(YP~Ov(YP!c(YP!g(YP!x(YP#o(YP#v(YP$_(YP$`(YP$a(YP$b(YP$c(YP%W(YP%Y(YP%Z(YP%](YP%^(YP%_(YP%`(YP%a(YP%b(YP%c(YP%d(YP%e(YP%f(YP%g(YP%h(YP%i(YP%j(YP%k(YP%m(YP%n(YP%o(YP%p(YP%q(YP%r(YP%s(YP&{(YP'n(YPr(YPt(YP#e(YP~PB{OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO!c(YP!g(YP!x(YP#o(YP#v(YP$_(YP$`(YP$a(YP$b(YP$c(YP%W(YP%Y(YP%Z(YP%](YP%^(YP%_(YP%`(YP%a(YP%b(YP%c(YP%d(YP%e(YP%f(YP%g(YP%h(YP%i(YP%j(YP%k(YP%m(YP%n(YP%o(YP%p(YP%q(YP%r(YP%s(YP&{(YP'n(YP!d(YPr(YPt(YP#e(YP~Ov$mOw-|O!O-{Oo'zX~P&'jOQ]OR#dOS#kOT#}OU$OOj.OOkROlROp%XOwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO!d(YP~Ow%]O!OmOv(YP~P&'jOo%TOv#mXw#mX!O#mX!Q#mX![#mX!c#mX!e#mX!g#mX!o#mX!x#mX#T#mX#V#mX#X#mX#o#mX#v#mX$_#mX$`#mX$a#mX$b#mX$c#mX%W#mX%Y#mX%Z#mX%]#mX%^#mX%_#mX%`#mX%a#mX%b#mX%c#mX%d#mX%e#mX%f#mX%g#mX%h#mX%i#mX%j#mX%k#mX%m#mX%n#mX%o#mX%p#mX%q#mX%r#mX%s#mX%y#mX&{#mX'n#mX!d#mXr#mXt#mX#e#mX~O!e(QOv&maw&ma!O&ma!Q&ma![&ma!c&ma!g&ma!o&ma!x&ma#T&ma#V&ma#X&ma#o&ma#v&ma$_&ma$`&ma$a&ma$b&ma$c&ma%W&ma%Y&ma%Z&ma%]&ma%^&ma%_&ma%`&ma%a&ma%b&ma%c&ma%d&ma%e&ma%f&ma%g&ma%h&ma%i&ma%j&ma%k&ma%m&ma%n&ma%o&ma%p&ma%q&ma%r&ma%s&ma%y&ma&{&ma'n&ma!d&mar&mat&ma#e&ma~Op.SO~Ov$mOw$nO!O$lO%Z%wO%b%zO%c%{O%d%|O%e%}O%g&QO%h&RO%j&UO%y&iO#V&ra#o&ra%W&ra%Y&ra%k&ra%m&ra%n&ra%o&ra%p&ra%q&ra%r&ra%s&ra&{&ra'n&ra!d&rar&rat&ra#e&ra~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%]&[O%^&[O%_&^O%`&_O%a&OO%f&SO%i&`O!c&ra!g&ra#v&ra$_&ra$`&ra$a&ra$b&ra$c&ra~P&<aOX.UO~Oo%TOQ&ZXR&ZXS&ZXT&ZXU&ZXj&nXk&ZXl&ZXp&nXv&xaw&xax&ZXz&ZX}&ZX!O&xa!P&ZX!Q&xa!R&ZX!T&ZX!X&ZX!Y&ZX![&xa!^&ZX!_&ZX!`&ZX!a&ZX!e&ZX!i&ZX!l&ZX!o&xa!t&ZX!v&ZX!x&xa!z&ZX!|&ZX#O&ZX#P&ZX#R&ZX#T&xa#V&xa#X&xa#[&ZX#]&ZX#^&ZX#_&ZX#a&ZX#o&xa%W&xa%Y&xa%Z&xa%]&xa%^&xa%_&xa%`&xa%a&xa%b&xa%c&xa%d&xa%e&xa%f&xa%g&xa%h&xa%i&xa%j&xa%k&xa%m&xa%n&xa%o&xa%p&xa%q&xa%r&xa%s&xa%u&ZX%v&ZX%w&ZX%y&xa%{&ZX%|&ZX%}&ZX&O&ZX&P&ZX&Q&ZX&T&ZX&U&ZX&V&ZX&W&ZX&X&ZX&_&ZX&a&ZX&b&ZX&c&ZX&h&ZX&i&ZX&k&ZX&w&ZX&y&ZX&{&xa&}&ZX'O&ZX'P&ZX'R&ZX'S&ZX'U&ZX'V&ZX'W&ZX'n&xa't&ZX(O&ZX(]&ZX*f&ZX!d&xar&xat&xa#e&xa~O!c&xa!g&xa#v&xa$_&xa$`&xa$a&xa$b&xa$c&xa~P&?{Ov$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%f&SO%g&QO%h&RO%i&`O%j&UO%k&VO%m&cO%n&dO%o&eO%p&fO%y&iO&{&jO~O!c&xa!g&xa#o&xa#v&xa$_&xa$`&xa$a&xa$b&xa$c&xa%W&xa%Y&xa%q&xa%r&xa%s&xa'n&xa!d&xar&xat&xa#e&xa~P&HSOk.WO#R!OO~Ok.XO#R!OO~Ok.YOl.YO#R!OO#T!PO~OZ.[O~OZ.]O~P+vOv$mOw$nO!O$lO!Q5WO![5XO!o5WO!x5VO#T5VO#V&WO#X5VO%W4}O%Y5OO%Z%wO%]5UO%^5UO%_5WO%`5XO%a5QO%b%zO%c%{O%d%|O%e%}O%f5SO%g&QO%h&RO%i5YO%j&UO%k&VO%m5]O%n5^O%o5_O%p5`O%q&XO%r&YO%s&ZO%y&iO&{6eO~Or.^O~P&LeOp.aO~P$ |O!e(QOv&jiw&ji!O&ji!Q&ji![&ji!c&ji!g&ji!o&ji!x&ji#T&ji#V&ji#X&ji#o&ji#v&ji$_&ji$`&ji$a&ji$b&ji$c&ji%W&ji%Y&ji%Z&ji%]&ji%^&ji%_&ji%`&ji%a&ji%b&ji%c&ji%d&ji%e&ji%f&ji%g&ji%h&ji%i&ji%j&ji%k&ji%m&ji%n&ji%o&ji%p&ji%q&ji%r&ji%s&ji%y&ji&{&ji'n&ji!d&jir&jit&ji#e&ji~Oo.dO~Oo%TOt.eO!c4zOj&nXp&nXw&qX!O#YX!Q#YX![#YX!o#YX!x#YX#T#YX#V#YX#X#YX%W#YX%Y#YX%Z#YX%]#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%m#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%y#YX&{#YX~P!M{Ot.eO~P&LeOg.gO'x$oO^'}a~O`.iO~Oa.jO~Oo.kO~O'r*QO'sna~Oj.mOp.mOxYOzSO}VO(OUO~Ow.nO!O.oO~Ov.pOw.nO!O.oO~Oj.qOxYOzSO}VO!P.qO!Q.rO!R.qO(OUO~Oo.sO~O`.tO~P+vO%W%vO%Y%xO!c!bi!g!bi#o!bi#v!bi$_!bi$`!bi$a!bi$b!bi$c!bi%q!bi%r!bi%s!bi'n!bi!d!bir!bit!bi#e!bi~P&HSOt.xO~P`Ow%]O!c'_X!d'_X!g'_Xr'_Xt'_X#o'_X'n'_X~PN`O!c'kO!g'kO!d(Yar(Yat(Ya~O`.|Ob*nO~Ot.}O~P&LeOt/QO~O%W%vO%Y%xO!c%Vi!g%Vi#o%Vi#v%Vi$_%Vi$`%Vi$a%Vi$b%Vi$c%Vi%q%Vi%r%Vi%s%Vi'n%Vi!d%Vir%Vit%Vi#e%Vi~P&HSO%W%vO%Y%xO!c%Xi!g%Xi#o%Xi#v%Xi$_%Xi$`%Xi$a%Xi$b%Xi$c%Xi%q%Xi%r%Xi%s%Xi'n%Xi!d%Xir%Xit%Xi#e%Xi~P&HSOv$mOw$nO!O$lO%]&[O%y&iO!Q%[i![%[i!c%[i!g%[i!o%[i!x%[i#T%[i#V%[i#X%[i#o%[i#v%[i$_%[i$`%[i$a%[i$b%[i$c%[i%W%[i%Y%[i%Z%[i%_%[i%`%[i%a%[i%b%[i%c%[i%d%[i%e%[i%f%[i%g%[i%h%[i%i%[i%j%[i%k%[i%m%[i%n%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[i'n%[i!d%[ir%[it%[i#e%[i~O%^&[O~P'/mOv$mOw$nO!O$lO%Z%wO%y&iO#V'ja#o'ja%W'ja%Y'ja%a'ja%b'ja%c'ja%d'ja%e'ja%f'ja%g'ja%h'ja%i'ja%j'ja%k'ja%m'ja%n'ja%o'ja%p'ja%q'ja%r'ja%s'ja&{'ja'n'ja!d'jar'jat'ja#e'ja~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%]&[O%^&[O%_&^O%`&_O!c'ja!g'ja#v'ja$_'ja$`'ja$a'ja$b'ja$c'ja~P'3SOv$mOw$nO!O$lO%Z%wO%b%zO%c%{O%d%|O%e%}O%y&iO#V'ka#o'ka%W'ka%Y'ka%f'ka%g'ka%h'ka%i'ka%j'ka%k'ka%m'ka%n'ka%o'ka%p'ka%q'ka%r'ka%s'ka&{'ka'n'ka!d'kar'kat'ka#e'ka~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%]&[O%^&[O%_&^O%`&_O%a&OO!c'ka!g'ka#v'ka$_'ka$`'ka$a'ka$b'ka$c'ka~P'6iO%^%[i~P'/mOv$mOw$nO!O$lO!x&]O#T&]O#X&]O%Z%wO%]&[O%^&[O%y&iO![%[i!c%[i!g%[i#V%[i#o%[i#v%[i$_%[i$`%[i$a%[i$b%[i$c%[i%W%[i%Y%[i%`%[i%a%[i%b%[i%c%[i%d%[i%e%[i%f%[i%g%[i%h%[i%i%[i%j%[i%k%[i%m%[i%n%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[i'n%[i!d%[ir%[it%[i#e%[i~O!Q%[i!o%[i%_%[i~P':VO!Q&^O!o&^O%_&^O~P':VOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%y&iO!c%[i!g%[i#V%[i#o%[i#v%[i$_%[i$`%[i$a%[i$b%[i$c%[i%W%[i%Y%[i%k%[i%m%[i%n%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[i'n%[i!d%[ir%[it%[i#e%[i~O%f%[i%g%[i%h%[i%i%[i%j%[i~P'=yO%f&SO%g&QO%h&RO%i&`O%j&UO~P'=yOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%f&SO%g&QO%h&RO%i&`O%j&UO%k&VO%y&iO!c%[i!g%[i#o%[i#v%[i$_%[i$`%[i$a%[i$b%[i$c%[i%W%[i%Y%[i%m%[i%n%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[i'n%[i!d%[ir%[it%[i#e%[i~O#V%[i~P'AsO#V&WO~P'AsOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%f&SO%g&QO%h&RO%i&`O%j&UO%k&VO%m&cO%y&iO!c%[i!g%[i#o%[i#v%[i$_%[i$`%[i$a%[i$b%[i$c%[i%W%[i%Y%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[i'n%[i!d%[ir%[it%[i#e%[i~O%n%[i~P'EaO%n&dO~P'EaOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%Z%wO%]&[O%^&[O%_&^O%`&_O%a&OO%b%zO%c%{O%d%|O%e%}O%f&SO%g&QO%h&RO%i&`O%j&UO%k&VO%m&cO%n&dO%o&eO%y&iO!c%[i!g%[i#o%[i#v%[i$_%[i$`%[i$a%[i$b%[i$c%[i%q%[i%r%[i%s%[i'n%[i!d%[ir%[it%[i#e%[i~O%W%[i%Y%[i%p%[i&{%[i~P'H}O%W%vO%Y%xO%p&fO&{&jO~P'H}O%W%vO%Y%xO%q&XO!c%[i!g%[i#o%[i#v%[i$_%[i$`%[i$a%[i$b%[i$c%[i%r%[i%s%[i'n%[i!d%[ir%[it%[i#e%[i~P&HSO#e/TO~P&LeO`/VO~O`/VO~P+vO`/VOa/WO~P+vO`/YO~Oc/[O'u/ZO~O`/YO~P+vO`/YOa/]O~P+vOc/`O'u/_O~O!x/aO~P+vO`/bO~Oc/dO'u/cO~O`/bO~P+vO`/bOa/eO~P+vO^/gO'x$oO~O_+uO`+vO~O`/kOa/jO~P+vO_+uO`+vO~P+vO_+uO`+vOa/mO~P+vOa/pO~Ot/qO~P&LeOt/rO~P&LeOt/sO~P&LeO!c#ma!g#ma!x#ma#v#ma$_#ma$`#ma$a#ma$b#ma$c#ma%W#ma%Y#ma%Z#ma%]#ma%^#ma%_#ma%`#ma%a#ma%b#ma%c#ma%d#ma%e#ma%f#ma%g#ma%h#ma%i#ma%j#ma%k#ma%m#ma%n#ma%o#ma%p#ma%q#ma%r#ma%s#ma&{#ma!d#mar#mat#ma#e#ma~P$+rOt/tO~P&LeOQ]OjROkROlRO!X/uO~O!c'kO!g'kO!d(jX~O!d/xO~Oo%TOw#ma#n#ma#o#ma'n#ma~Ow'xO#o'nO'n'nO~OQ#maR#maS#maT#maU#maj#mak#mal#map#max#maz#ma}#ma!O#ma!P#ma!Q#ma!R#ma!T#ma!X#ma!Y#ma![#ma!^#ma!_#ma!`#ma!a#ma!e#ma!i#ma!l#ma!o#ma!t#ma!v#ma!z#ma!|#ma#O#ma#P#ma#R#ma#T#ma#V#ma#X#ma#[#ma#]#ma#^#ma#_#ma#a#ma%u#ma%v#ma%w#ma%y#ma%{#ma%|#ma%}#ma&O#ma&P#ma&Q#ma&T#ma&U#ma&V#ma&W#ma&X#ma&_#ma&a#ma&b#ma&c#ma&h#ma&i#ma&k#ma&w#ma&y#ma&}#ma'O#ma'P#ma'R#ma'S#ma'U#ma'V#ma'W#ma't#ma(O#ma(]#ma*f#ma!c#ma!g#ma~P('gO!c(ta!g(ta~P%1oOp'XO#s0RO~P%-TO!c'kO!g'kO#o)OX'n)OX~O!g0]O~O!d0^O~O!d0_O~O!e(QO#e#daw#da#o#da'n#da~O!e0aO~Ow'xO#e-UO#o'nO'n'nO~Op,xO~O!c'kO!g'kO#v)Ua$_)Ua$`)Ua$a)Ua$b)Ua$c)Ua#o)Ua'n)Ua~O$f0hO$h0lOQ$diR$diS$diT$diU$did$dij$dik$dil$dip$diw$dix$diz$di}$di!O$di!P$di!Q$di!R$di!T$di!X$di!Y$di![$di!^$di!_$di!`$di!a$di!e$di!i$di!l$di!o$di!t$di!v$di!z$di!|$di#O$di#P$di#R$di#T$di#V$di#X$di#[$di#]$di#^$di#_$di#a$di#l$di#o$di#q$di#r$di#v$di$P$di$Y$di$^$di$_$di$`$di$a$di$b$di$c$di$v$di$w$di$x$di$y$di$z$di%P$di%Q$di%u$di%v$di%w$di%y$di%{$di%|$di%}$di&O$di&P$di&Q$di&T$di&U$di&V$di&W$di&X$di&_$di&a$di&b$di&c$di&h$di&i$di&k$di&w$di&y$di&}$di'O$di'P$di'R$di'S$di'U$di'V$di'W$di'm$di't$di(O$di(]$di)e$di*f$dit$di%S$di%T$di%U$di~O$f0hO$h0lOQ$iiR$iiS$iiT$iiU$iid$iij$iik$iil$iip$iiw$iix$iiz$ii}$ii!O$ii!P$ii!Q$ii!R$ii!T$ii!X$ii!Y$ii![$ii!^$ii!_$ii!`$ii!a$ii!e$ii!i$ii!l$ii!o$ii!t$ii!v$ii!z$ii!|$ii#O$ii#P$ii#R$ii#T$ii#V$ii#X$ii#[$ii#]$ii#^$ii#_$ii#a$ii#l$ii#o$ii#q$ii#r$ii#v$ii$P$ii$Y$ii$^$ii$_$ii$`$ii$a$ii$b$ii$c$ii$v$ii$w$ii$x$ii$y$ii$z$ii%P$ii%Q$ii%u$ii%v$ii%w$ii%y$ii%{$ii%|$ii%}$ii&O$ii&P$ii&Q$ii&T$ii&U$ii&V$ii&W$ii&X$ii&_$ii&a$ii&b$ii&c$ii&h$ii&i$ii&k$ii&w$ii&y$ii&}$ii'O$ii'P$ii'R$ii'S$ii'U$ii'V$ii'W$ii'm$ii't$ii(O$ii(]$ii)e$ii*f$iit$ii%S$ii%T$ii%U$ii~O$m(`OQ$jiR$jiS$jiT$jiU$jid$jij$jik$jil$jip$jiw$jix$jiz$ji}$ji!O$ji!P$ji!Q$ji!R$ji!T$ji!X$ji!Y$ji![$ji!^$ji!_$ji!`$ji!a$ji!e$ji!i$ji!l$ji!o$ji!t$ji!v$ji!z$ji!|$ji#O$ji#P$ji#R$ji#T$ji#V$ji#X$ji#[$ji#]$ji#^$ji#_$ji#a$ji#l$ji#o$ji#q$ji#r$ji#v$ji$P$ji$Y$ji$^$ji$_$ji$`$ji$a$ji$b$ji$c$ji$v$ji$w$ji$x$ji$y$ji$z$ji%P$ji%Q$ji%u$ji%v$ji%w$ji%y$ji%{$ji%|$ji%}$ji&O$ji&P$ji&Q$ji&T$ji&U$ji&V$ji&W$ji&X$ji&_$ji&a$ji&b$ji&c$ji&h$ji&i$ji&k$ji&w$ji&y$ji&}$ji'O$ji'P$ji'R$ji'S$ji'U$ji'V$ji'W$ji'm$ji't$ji(O$ji(]$ji)e$ji*f$jit$ji%S$ji%T$ji%U$ji~Oj0xO~Ol0xO#[!SO#]!TO#^!UO#_!VO~O#o'nO'n'nOQ$riR$riS$riT$riU$rid$rij$rik$ril$rip$riw$rix$riz$ri}$ri!O$ri!P$ri!Q$ri!R$ri!T$ri!X$ri!Y$ri![$ri!^$ri!_$ri!`$ri!a$ri!e$ri!i$ri!l$ri!o$ri!t$ri!v$ri!z$ri!|$ri#O$ri#P$ri#R$ri#T$ri#V$ri#X$ri#[$ri#]$ri#^$ri#_$ri#a$ri#l$ri#o$ri#q$ri#r$ri#v$ri$P$ri$Y$ri$^$ri$_$ri$`$ri$a$ri$b$ri$c$ri$v$ri$w$ri$x$ri$y$ri$z$ri%P$ri%Q$ri%u$ri%v$ri%w$ri%y$ri%{$ri%|$ri%}$ri&O$ri&P$ri&Q$ri&T$ri&U$ri&V$ri&W$ri&X$ri&_$ri&a$ri&b$ri&c$ri&h$ri&i$ri&k$ri&w$ri&y$ri&}$ri'O$ri'P$ri'R$ri'S$ri'U$ri'V$ri'W$ri'm$ri't$ri(O$ri(]$ri)e$ri*f$rit$ri%S$ri%T$ri%U$ri~O$m(`OQ$niR$niS$niT$niU$nid$nij$nik$nil$nip$niw$nix$niz$ni}$ni!O$ni!P$ni!Q$ni!R$ni!T$ni!X$ni!Y$ni![$ni!^$ni!_$ni!`$ni!a$ni!e$ni!i$ni!l$ni!o$ni!t$ni!v$ni!z$ni!|$ni#O$ni#P$ni#R$ni#T$ni#V$ni#X$ni#[$ni#]$ni#^$ni#_$ni#a$ni#l$ni#o$ni#q$ni#r$ni#v$ni$P$ni$Y$ni$^$ni$_$ni$`$ni$a$ni$b$ni$c$ni$v$ni$w$ni$x$ni$y$ni$z$ni%P$ni%Q$ni%u$ni%v$ni%w$ni%y$ni%{$ni%|$ni%}$ni&O$ni&P$ni&Q$ni&T$ni&U$ni&V$ni&W$ni&X$ni&_$ni&a$ni&b$ni&c$ni&h$ni&i$ni&k$ni&w$ni&y$ni&}$ni'O$ni'P$ni'R$ni'S$ni'U$ni'V$ni'W$ni'm$ni't$ni(O$ni(]$ni)e$ni*f$nit$ni%S$ni%T$ni%U$ni~O#o'nO'n'nO~P$1sO$m(`OQ$piR$piS$piT$piU$pid$pij$pik$pil$pip$piw$pix$piz$pi}$pi!O$pi!P$pi!Q$pi!R$pi!T$pi!X$pi!Y$pi![$pi!^$pi!_$pi!`$pi!a$pi!e$pi!i$pi!l$pi!o$pi!t$pi!v$pi!z$pi!|$pi#O$pi#P$pi#R$pi#T$pi#V$pi#X$pi#[$pi#]$pi#^$pi#_$pi#a$pi#l$pi#o$pi#q$pi#r$pi#v$pi$P$pi$Y$pi$^$pi$_$pi$`$pi$a$pi$b$pi$c$pi$v$pi$w$pi$x$pi$y$pi$z$pi%P$pi%Q$pi%u$pi%v$pi%w$pi%y$pi%{$pi%|$pi%}$pi&O$pi&P$pi&Q$pi&T$pi&U$pi&V$pi&W$pi&X$pi&_$pi&a$pi&b$pi&c$pi&h$pi&i$pi&k$pi&w$pi&y$pi&}$pi'O$pi'P$pi'R$pi'S$pi'U$pi'V$pi'W$pi'm$pi't$pi(O$pi(]$pi)e$pi*f$pit$pi%S$pi%T$pi%U$pi~Ol0xO~Ow%]Ov'_X!c'_X!g'_X!x'_X#o'_X#v'_X$_'_X$`'_X$a'_X$b'_X$c'_X%W'_X%Y'_X%Z'_X%]'_X%^'_X%_'_X%`'_X%a'_X%b'_X%c'_X%d'_X%e'_X%f'_X%g'_X%h'_X%i'_X%j'_X%k'_X%m'_X%n'_X%o'_X%p'_X%q'_X%r'_X%s'_X&{'_X'n'_X!d'_Xr'_Xt'_X#e'_X~PN`O!c'kO!g'kO#o(sa'n(sa!d(sa~Ov(saw(sa!O(sa!Q(sa![(sa!o(sa!x(sa#T(sa#V(sa#X(sa#v(sa$_(sa$`(sa$a(sa$b(sa$c(sa%W(sa%Y(sa%Z(sa%](sa%^(sa%_(sa%`(sa%a(sa%b(sa%c(sa%d(sa%e(sa%f(sa%g(sa%h(sa%i(sa%j(sa%k(sa%m(sa%n(sa%o(sa%p(sa%q(sa%r(sa%s(sa%y(sa&{(sar(sat(sa#e(sa~P)0iO!c'kO!g'kOv)QXw)QX!O)QX!Q)QX![)QX!o)QX!x)QX#T)QX#V)QX#X)QX#o)QX#v)QX$_)QX$`)QX$a)QX$b)QX$c)QX%W)QX%Y)QX%Z)QX%])QX%^)QX%_)QX%`)QX%a)QX%b)QX%c)QX%d)QX%e)QX%f)QX%g)QX%h)QX%i)QX%j)QX%k)QX%m)QX%n)QX%o)QX%p)QX%q)QX%r)QX%s)QX%y)QX&{)QX'n)QX!d)QXr)QXt)QX#e)QX~O!c'kO!d1TO!g'kO~Ov$mOw$nO!O$lO%y&iO!c*Xa!g*Xa!d*Xa~O!Q*Xa![*Xa!o*Xa!x*Xa#T*Xa#V*Xa#X*Xa#o*Xa#v*Xa$_*Xa$`*Xa$a*Xa$b*Xa$c*Xa%W*Xa%Y*Xa%Z*Xa%]*Xa%^*Xa%_*Xa%`*Xa%a*Xa%b*Xa%c*Xa%d*Xa%e*Xa%f*Xa%g*Xa%h*Xa%i*Xa%j*Xa%k*Xa%m*Xa%n*Xa%o*Xa%p*Xa%q*Xa%r*Xa%s*Xa&{*Xa'n*Xar*Xat*Xa#e*Xa~P)7lOv(Yaw(Ya!O(Ya!Q(Ya![(Ya!o(Ya!x(Ya#T(Ya#V(Ya#X(Ya#o(Ya#v(Ya$_(Ya$`(Ya$a(Ya$b(Ya$c(Ya%W(Ya%Y(Ya%Z(Ya%](Ya%^(Ya%_(Ya%`(Ya%a(Ya%b(Ya%c(Ya%d(Ya%e(Ya%f(Ya%g(Ya%h(Ya%i(Ya%j(Ya%k(Ya%m(Ya%n(Ya%o(Ya%p(Ya%q(Ya%r(Ya%s(Ya%y(Ya&{(Ya'n(Ya#e(Ya~P',WO!d1VO~Op5lOt(YP~P#?|OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOv$mOw-|OxXOzSO}VO!O-{O!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$POo'zX!c'zX!d(YP!g'zX~O!x'zX%W'zX%Y'zX%Z'zX%]'zX%^'zX%_'zX%`'zX%a'zX%b'zX%c'zX%d'zX%e'zX%f'zX%g'zX%h'zX%i'zX%j'zX%k'zX%m'zX%n'zX%o'zX%p'zX%q'zX%r'zX%s'zX&{'zX~P)>fO!d1[O~Oj1]Op)YO~O!d1`O~O!d1aO~Ot1bO~P&LeO!c'kO!g'kOr*WXv*WXw*WX!O*WX!Q*WX![*WX!o*WX!x*WX#T*WX#V*WX#X*WX%W*WX%Y*WX%Z*WX%]*WX%^*WX%_*WX%`*WX%a*WX%b*WX%c*WX%d*WX%e*WX%f*WX%g*WX%h*WX%i*WX%j*WX%k*WX%m*WX%n*WX%o*WX%p*WX%q*WX%r*WX%s*WX%y*WX&{*WXt*WX#e*WX#o*WX'n*WX!d*WX~Or1cO~P&LeOo%TOt1dO!c4zOj&nXp&nXw&qX!O#YX!Q#YX![#YX!o#YX!x#YX#T#YX#V#YX#X#YX%W#YX%Y#YX%Z#YX%]#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%m#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%y#YX&{#YX~P!M{Ot1dO~P&LeOp)wO~Og1fO'x$oO~Og.gO'x$oO^'}i~O`1hO~OP1iOp1iO~Ot1jO~Oj1kOp1kOxYOzSO}VO(OUO~Oj1lOxYOzSO}VO!P1lO!Q1mO!R1lO(OUO~Ow1nO!O1oO~Or1pO~O!P1lO~OP1qOp1qO~O`1sO~P+vO!c'_a!d'_a!g'_ar'_at'_a#o'_a#v'_a$_'_a$`'_a$a'_a$b'_a$c'_a'n'_a#e'_a~P%1oOv!niv!nqw!niw!nq!O!ni!O!nq!Q!ni!Q!nq![!ni![!nq!c!ni!c!nq!g!ni!g!nq!o!ni!o!nq!x!ni!x!nq#T!ni#T!nq#V!ni#V!nq#X!ni#X!nq#o!ni#o!nq#v!ni#v!nq$_!ni$_!nq$`!ni$`!nq$a!ni$a!nq$b!ni$b!nq$c!ni$c!nq%W!ni%W!nq%Y!ni%Y!nq%Z!ni%Z!nq%]!ni%]!nq%^!ni%^!nq%_!ni%_!nq%`!ni%`!nq%a!ni%a!nq%b!ni%b!nq%c!ni%c!nq%d!ni%d!nq%e!ni%e!nq%f!ni%f!nq%g!ni%g!nq%h!ni%h!nq%i!ni%i!nq%j!ni%j!nq%k!ni%k!nq%m!ni%m!nq%n!ni%n!nq%o!ni%o!nq%p!ni%p!nq%q!ni%q!nq%r!ni%r!nq%s!ni%s!nq%y!ni%y!nq&{!ni&{!nq'n!ni'n!nq!d!ni!d!nqr!nir!nqt!nit!nq#e!ni#e!nq~O%W%vO%Y%xO!c%Xq!g%Xq#o%Xq#v%Xq$_%Xq$`%Xq$a%Xq$b%Xq$c%Xq%q%Xq%r%Xq%s%Xq'n%Xq!d%Xqr%Xqt%Xq#e%Xq~P&HSO!c&zq!g&zq#o&zq#v&zq$_&zq$`&zq$a&zq$b&zq$c&zq%W&zq%Y&zq%q&zq%r&zq%s&zq'n&zq!d&zqr&zqt&zq#e&zq~P&HSO`1wO~O`1wO~P+vOc1yO'u1xO~O`1zO~O`1zO~P+vO'u1{O~Oc1|O'u1{O~Oc2OO'u1}O~O`2PO~O`2PO~P+vO^2QO~O`2SOa2RO~P+vO`2SO~Oc2VO'u2UO~O`2SO~P+vOa2XO~O!d2ZO~O!c'aX!d'aX!g'aX~P$NjO!c'kO!g'kO!d(ja~O!c'kO!g'kO#n2gO#o'nO'n'nO~P$:VO!d2iO~O!e,nO!c'eX!g'eX#o'eX'n'eX~P%-TO!c'kO!g'kO#o)Oa'n)Oa~O!e,nO!iiO#o)OP'n)OP~P%-TO!d,uO#c,vO~O$f0hO$h0lOQ$dqR$dqS$dqT$dqU$dqd$dqj$dqk$dql$dqp$dqw$dqx$dqz$dq}$dq!O$dq!P$dq!Q$dq!R$dq!T$dq!X$dq!Y$dq![$dq!^$dq!_$dq!`$dq!a$dq!e$dq!i$dq!l$dq!o$dq!t$dq!v$dq!z$dq!|$dq#O$dq#P$dq#R$dq#T$dq#V$dq#X$dq#[$dq#]$dq#^$dq#_$dq#a$dq#l$dq#o$dq#q$dq#r$dq#v$dq$P$dq$Y$dq$^$dq$_$dq$`$dq$a$dq$b$dq$c$dq$v$dq$w$dq$x$dq$y$dq$z$dq%P$dq%Q$dq%u$dq%v$dq%w$dq%y$dq%{$dq%|$dq%}$dq&O$dq&P$dq&Q$dq&T$dq&U$dq&V$dq&W$dq&X$dq&_$dq&a$dq&b$dq&c$dq&h$dq&i$dq&k$dq&w$dq&y$dq&}$dq'O$dq'P$dq'R$dq'S$dq'U$dq'V$dq'W$dq'm$dq't$dq(O$dq(]$dq)e$dq*f$dqt$dq%S$dq%T$dq%U$dq~O$f0hO$h0lOQ$iqR$iqS$iqT$iqU$iqd$iqj$iqk$iql$iqp$iqw$iqx$iqz$iq}$iq!O$iq!P$iq!Q$iq!R$iq!T$iq!X$iq!Y$iq![$iq!^$iq!_$iq!`$iq!a$iq!e$iq!i$iq!l$iq!o$iq!t$iq!v$iq!z$iq!|$iq#O$iq#P$iq#R$iq#T$iq#V$iq#X$iq#[$iq#]$iq#^$iq#_$iq#a$iq#l$iq#o$iq#q$iq#r$iq#v$iq$P$iq$Y$iq$^$iq$_$iq$`$iq$a$iq$b$iq$c$iq$v$iq$w$iq$x$iq$y$iq$z$iq%P$iq%Q$iq%u$iq%v$iq%w$iq%y$iq%{$iq%|$iq%}$iq&O$iq&P$iq&Q$iq&T$iq&U$iq&V$iq&W$iq&X$iq&_$iq&a$iq&b$iq&c$iq&h$iq&i$iq&k$iq&w$iq&y$iq&}$iq'O$iq'P$iq'R$iq'S$iq'U$iq'V$iq'W$iq'm$iq't$iq(O$iq(]$iq)e$iq*f$iqt$iq%S$iq%T$iq%U$iq~O$m(`OQ$jqR$jqS$jqT$jqU$jqd$jqj$jqk$jql$jqp$jqw$jqx$jqz$jq}$jq!O$jq!P$jq!Q$jq!R$jq!T$jq!X$jq!Y$jq![$jq!^$jq!_$jq!`$jq!a$jq!e$jq!i$jq!l$jq!o$jq!t$jq!v$jq!z$jq!|$jq#O$jq#P$jq#R$jq#T$jq#V$jq#X$jq#[$jq#]$jq#^$jq#_$jq#a$jq#l$jq#o$jq#q$jq#r$jq#v$jq$P$jq$Y$jq$^$jq$_$jq$`$jq$a$jq$b$jq$c$jq$v$jq$w$jq$x$jq$y$jq$z$jq%P$jq%Q$jq%u$jq%v$jq%w$jq%y$jq%{$jq%|$jq%}$jq&O$jq&P$jq&Q$jq&T$jq&U$jq&V$jq&W$jq&X$jq&_$jq&a$jq&b$jq&c$jq&h$jq&i$jq&k$jq&w$jq&y$jq&}$jq'O$jq'P$jq'R$jq'S$jq'U$jq'V$jq'W$jq'm$jq't$jq(O$jq(]$jq)e$jq*f$jqt$jq%S$jq%T$jq%U$jq~O$m(`OQ$nqR$nqS$nqT$nqU$nqd$nqj$nqk$nql$nqp$nqw$nqx$nqz$nq}$nq!O$nq!P$nq!Q$nq!R$nq!T$nq!X$nq!Y$nq![$nq!^$nq!_$nq!`$nq!a$nq!e$nq!i$nq!l$nq!o$nq!t$nq!v$nq!z$nq!|$nq#O$nq#P$nq#R$nq#T$nq#V$nq#X$nq#[$nq#]$nq#^$nq#_$nq#a$nq#l$nq#o$nq#q$nq#r$nq#v$nq$P$nq$Y$nq$^$nq$_$nq$`$nq$a$nq$b$nq$c$nq$v$nq$w$nq$x$nq$y$nq$z$nq%P$nq%Q$nq%u$nq%v$nq%w$nq%y$nq%{$nq%|$nq%}$nq&O$nq&P$nq&Q$nq&T$nq&U$nq&V$nq&W$nq&X$nq&_$nq&a$nq&b$nq&c$nq&h$nq&i$nq&k$nq&w$nq&y$nq&}$nq'O$nq'P$nq'R$nq'S$nq'U$nq'V$nq'W$nq'm$nq't$nq(O$nq(]$nq)e$nq*f$nqt$nq%S$nq%T$nq%U$nq~O$m(`OQ$pqR$pqS$pqT$pqU$pqd$pqj$pqk$pql$pqp$pqw$pqx$pqz$pq}$pq!O$pq!P$pq!Q$pq!R$pq!T$pq!X$pq!Y$pq![$pq!^$pq!_$pq!`$pq!a$pq!e$pq!i$pq!l$pq!o$pq!t$pq!v$pq!z$pq!|$pq#O$pq#P$pq#R$pq#T$pq#V$pq#X$pq#[$pq#]$pq#^$pq#_$pq#a$pq#l$pq#o$pq#q$pq#r$pq#v$pq$P$pq$Y$pq$^$pq$_$pq$`$pq$a$pq$b$pq$c$pq$v$pq$w$pq$x$pq$y$pq$z$pq%P$pq%Q$pq%u$pq%v$pq%w$pq%y$pq%{$pq%|$pq%}$pq&O$pq&P$pq&Q$pq&T$pq&U$pq&V$pq&W$pq&X$pq&_$pq&a$pq&b$pq&c$pq&h$pq&i$pq&k$pq&w$pq&y$pq&}$pq'O$pq'P$pq'R$pq'S$pq'U$pq'V$pq'W$pq'm$pq't$pq(O$pq(]$pq)e$pq*f$pqt$pq%S$pq%T$pq%U$pq~Ol2{O~O!d2}O~Ov'fX!c'fX!g'fX!x'fX#o'fX#v'fX$_'fX$`'fX$a'fX$b'fX$c'fX%W'fX%Y'fX%Z'fX%]'fX%^'fX%_'fX%`'fX%a'fX%b'fX%c'fX%d'fX%e'fX%f'fX%g'fX%h'fX%i'fX%j'fX%k'fX%m'fX%n'fX%o'fX%p'fX%q'fX%r'fX%s'fX&{'fX'n'fX!d'fXr'fXt'fX#e'fX~P!-wO!c'kO!g'kOv)Qaw)Qa!O)Qa!Q)Qa![)Qa!o)Qa!x)Qa#T)Qa#V)Qa#X)Qa#o)Qa#v)Qa$_)Qa$`)Qa$a)Qa$b)Qa$c)Qa%W)Qa%Y)Qa%Z)Qa%])Qa%^)Qa%_)Qa%`)Qa%a)Qa%b)Qa%c)Qa%d)Qa%e)Qa%f)Qa%g)Qa%h)Qa%i)Qa%j)Qa%k)Qa%m)Qa%n)Qa%o)Qa%p)Qa%q)Qa%r)Qa%s)Qa%y)Qa&{)Qa'n)Qa!d)Qar)Qat)Qa#e)Qa~Ot3OO~Ov$mOw$nO!O$lO!Q*Wi![*Wi!c*Wi!g*Wi!o*Wi!x*Wi#T*Wi#V*Wi#X*Wi#o*Wi#v*Wi$_*Wi$`*Wi$a*Wi$b*Wi$c*Wi%W*Wi%Y*Wi%Z*Wi%]*Wi%^*Wi%_*Wi%`*Wi%a*Wi%b*Wi%c*Wi%d*Wi%e*Wi%f*Wi%g*Wi%h*Wi%i*Wi%j*Wi%k*Wi%m*Wi%n*Wi%o*Wi%p*Wi%q*Wi%r*Wi%s*Wi%y*Wi&{*Wi'n*Wi!d*Wir*Wit*Wi#e*Wi~O!d3QO~O!c'kO!g'kOr(YX~P%1oO!c'kO!g'kOt(YX~P%1oO!d3RO~O!e(QOv&mqw&mq!O&mq!Q&mq![&mq!c&mq!g&mq!o&mq!x&mq#T&mq#V&mq#X&mq#o&mq#v&mq$_&mq$`&mq$a&mq$b&mq$c&mq%W&mq%Y&mq%Z&mq%]&mq%^&mq%_&mq%`&mq%a&mq%b&mq%c&mq%d&mq%e&mq%f&mq%g&mq%h&mq%i&mq%j&mq%k&mq%m&mq%n&mq%o&mq%p&mq%q&mq%r&mq%s&mq%y&mq&{&mq'n&mq!d&mqr&mqt&mq#e&mq~O!e(QOv&jyw&jy!O&jy!Q&jy![&jy!c&jy!g&jy!o&jy!x&jy#T&jy#V&jy#X&jy#o&jy#v&jy$_&jy$`&jy$a&jy$b&jy$c&jy%W&jy%Y&jy%Z&jy%]&jy%^&jy%_&jy%`&jy%a&jy%b&jy%c&jy%d&jy%e&jy%f&jy%g&jy%h&jy%i&jy%j&jy%k&jy%m&jy%n&jy%o&jy%p&jy%q&jy%r&jy%s&jy%y&jy&{&jy'n&jy!d&jyr&jyt&jy#e&jy~Ot3XO~Or3YO~O!P3ZO~Oj3[Op3[OxYOzSO}VO(OUO~Oj3ZOxYOzSO}VO!P3ZO!Q3]O!R3ZO(OUO~Ov!fiw!fi!O!fi!Q!fi![!fi!o!fi!x!fi#T!fi#V!fi#X!fi%W!fi%Y!fi%Z!fi%]!fi%^!fi%_!fi%`!fi%a!fi%b!fi%c!fi%d!fi%e!fi%f!fi%g!fi%h!fi%i!fi%j!fi%k!fi%m!fi%n!fi%o!fi%p!fi%q!fi%r!fi%s!fi%y!fi&{!fi~O!c!fi!g!fi#o#gi'n#gi!d#gi~P+8pO!c&zy!g&zy#o&zy#v&zy$_&zy$`&zy$a&zy$b&zy$c&zy%W&zy%Y&zy%q&zy%r&zy%s&zy'n&zy!d&zyr&zyt&zy#e&zy~P&HSO'u3^O~Oc3_O'u3^O~O'u3`O~O'u3aO~Oc3bO'u3aO~O`3cO~Oc3eO'u3dO~O`3cO~P+vO`3cOa3fO~P+vO`3hO~Oa3iO~O!c'kO!g'kO#o'nO'n'nO~P$:VO#o'nO'n'nO~P&LeO!d3uO~O$m(`OQ$pyR$pyS$pyT$pyU$pyd$pyj$pyk$pyl$pyp$pyw$pyx$pyz$py}$py!O$py!P$py!Q$py!R$py!T$py!X$py!Y$py![$py!^$py!_$py!`$py!a$py!e$py!i$py!l$py!o$py!t$py!v$py!z$py!|$py#O$py#P$py#R$py#T$py#V$py#X$py#[$py#]$py#^$py#_$py#a$py#l$py#o$py#q$py#r$py#v$py$P$py$Y$py$^$py$_$py$`$py$a$py$b$py$c$py$v$py$w$py$x$py$y$py$z$py%P$py%Q$py%u$py%v$py%w$py%y$py%{$py%|$py%}$py&O$py&P$py&Q$py&T$py&U$py&V$py&W$py&X$py&_$py&a$py&b$py&c$py&h$py&i$py&k$py&w$py&y$py&}$py'O$py'P$py'R$py'S$py'U$py'V$py'W$py'm$py't$py(O$py(]$py)e$py*f$pyt$py%S$py%T$py%U$py~O!d3{O~P&LeO!d3|O~Or*]iv*]iw*]i!O*]i!Q*]i![*]i!c!fi!g!fi!o*]i!x*]i#T*]i#V*]i#X*]i%W*]i%Y*]i%Z*]i%]*]i%^*]i%_*]i%`*]i%a*]i%b*]i%c*]i%d*]i%e*]i%f*]i%g*]i%h*]i%i*]i%j*]i%k*]i%m*]i%n*]i%o*]i%p*]i%q*]i%r*]i%s*]i%y*]i&{*]it*]i#e*]i#o*]i'n*]i!d*]i~Or*div*diw*di!O*di!Q*di![*di!c!fi!g!fi!o*di!x*di#T*di#V*di#X*di%W*di%Y*di%Z*di%]*di%^*di%_*di%`*di%a*di%b*di%c*di%d*di%e*di%f*di%g*di%h*di%i*di%j*di%k*di%m*di%n*di%o*di%p*di%q*di%r*di%s*di%y*di&{*dit*di#e*di#o*di'n*di!d*di~Or3}O~Ot4OO~O!P4PO~O'u4QO~O'u4RO~Oc4TO'u4SO~O`4UO~O`4UO~P+vOc4WO'u4VO~O`4XO~O$m(`OQ$p!RR$p!RS$p!RT$p!RU$p!Rd$p!Rj$p!Rk$p!Rl$p!Rp$p!Rw$p!Rx$p!Rz$p!R}$p!R!O$p!R!P$p!R!Q$p!R!R$p!R!T$p!R!X$p!R!Y$p!R![$p!R!^$p!R!_$p!R!`$p!R!a$p!R!e$p!R!i$p!R!l$p!R!o$p!R!t$p!R!v$p!R!z$p!R!|$p!R#O$p!R#P$p!R#R$p!R#T$p!R#V$p!R#X$p!R#[$p!R#]$p!R#^$p!R#_$p!R#a$p!R#l$p!R#o$p!R#q$p!R#r$p!R#v$p!R$P$p!R$Y$p!R$^$p!R$_$p!R$`$p!R$a$p!R$b$p!R$c$p!R$v$p!R$w$p!R$x$p!R$y$p!R$z$p!R%P$p!R%Q$p!R%u$p!R%v$p!R%w$p!R%y$p!R%{$p!R%|$p!R%}$p!R&O$p!R&P$p!R&Q$p!R&T$p!R&U$p!R&V$p!R&W$p!R&X$p!R&_$p!R&a$p!R&b$p!R&c$p!R&h$p!R&i$p!R&k$p!R&w$p!R&y$p!R&}$p!R'O$p!R'P$p!R'R$p!R'S$p!R'U$p!R'V$p!R'W$p!R'm$p!R't$p!R(O$p!R(]$p!R)e$p!R*f$p!Rt$p!R%S$p!R%T$p!R%U$p!R~Or4cO~O'u4dO~Oc4eO'u4dO~O'u4fO~Oc4gO'u4fO~O$m(`OQ$p!ZR$p!ZS$p!ZT$p!ZU$p!Zd$p!Zj$p!Zk$p!Zl$p!Zp$p!Zw$p!Zx$p!Zz$p!Z}$p!Z!O$p!Z!P$p!Z!Q$p!Z!R$p!Z!T$p!Z!X$p!Z!Y$p!Z![$p!Z!^$p!Z!_$p!Z!`$p!Z!a$p!Z!e$p!Z!i$p!Z!l$p!Z!o$p!Z!t$p!Z!v$p!Z!z$p!Z!|$p!Z#O$p!Z#P$p!Z#R$p!Z#T$p!Z#V$p!Z#X$p!Z#[$p!Z#]$p!Z#^$p!Z#_$p!Z#a$p!Z#l$p!Z#o$p!Z#q$p!Z#r$p!Z#v$p!Z$P$p!Z$Y$p!Z$^$p!Z$_$p!Z$`$p!Z$a$p!Z$b$p!Z$c$p!Z$v$p!Z$w$p!Z$x$p!Z$y$p!Z$z$p!Z%P$p!Z%Q$p!Z%u$p!Z%v$p!Z%w$p!Z%y$p!Z%{$p!Z%|$p!Z%}$p!Z&O$p!Z&P$p!Z&Q$p!Z&T$p!Z&U$p!Z&V$p!Z&W$p!Z&X$p!Z&_$p!Z&a$p!Z&b$p!Z&c$p!Z&h$p!Z&i$p!Z&k$p!Z&w$p!Z&y$p!Z&}$p!Z'O$p!Z'P$p!Z'R$p!Z'S$p!Z'U$p!Z'V$p!Z'W$p!Z'm$p!Z't$p!Z(O$p!Z(]$p!Z)e$p!Z*f$p!Zt$p!Z%S$p!Z%T$p!Z%U$p!Z~O!d4lO~P&LeO'u4mO~O'u4nO~O!d4oO~P&LeOj&xOw&yO!T4xO~OR6bOS6nOT4tOp4{O!Q4yO!Y6^O!o6_O%u4yO%v4yO%y6aO~P#/tOR6bOS6nOT4tOp4{O!Q4yO!Y6^O!o6_O%u4yO%v4yO%y6aO~P#7xOp5jO~P$ |Oj)mOw)nO!T4xO~Oo%TO!c4zOj&nXp&nXr#YXw&qX!O#YX!Q#YX![#YX!o#YX!x#YX#T#YX#V#YX#X#YX%W#YX%Y#YX%Z#YX%]#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%m#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%y#YX&{#YXt#YX#e#YX#o#YX'n#YX!d#YX~P!M{O#o(YX#v(YX$_(YX$`(YX$a(YX$b(YX$c(YX'n(YXr(YXt(YX#e(YX~P$1sO%W5qO~P#JQOr%[av%[aw%[a!O%[a!Q%[a![%[a!o%[a!x%[a#T%[a#V%[a#X%[a%W%[a%Y%[a%Z%[a%]%[a%^%[a%_%[a%`%[a%i%[a%j%[a%k%[a%m%[a%n%[a%o%[a%p%[a%q%[a%r%[a%s%[a%y%[a&{%[at%[a#e%[a#o%[a'n%[a!d%[a~O%a5QO%b%zO%c%{O%d%|O%e%}O%f%[a%g%[a%h%[a~P,5XO%f5SO%g&QO%h&RO%a%[a%b%[a%c%[a%d%[a%e%[a~P,5XOv$mOw$nO!O$lO!Q)RX![)RX!c)RX!g)RX!o)RX!x)RX#T)RX#V)RX#X)RX#o)RX#v)RX$_)RX$`)RX$a)RX$b)RX$c)RX%W)RX%Y)RX%Z)RX%])RX%^)RX%_)RX%`)RX%a)RX%b)RX%c)RX%d)RX%e)RX%f)RX%g)RX%h)RX%i)RX%j)RX%k)RX%m)RX%n)RX%o)RX%p)RX%q)RX%r)RX%s)RX%y)RX&{)RX'n)RX!d)RXr)RXt)RX#e)RX~Ov$mOw$nO!O$lO!Q5WO![5XO!o5WO!x5VO#T5VO#V&WO#X5VO%W4}O%Y5OO%Z%wO%]5UO%^5UO%_5WO%`5XO%a5QO%b%zO%c%{O%d%|O%e%}O%f5SO%g&QO%h&RO%i5YO%j&UO%k&VO%m5]O%n5^O%o5_O%p5`O%y&iO&{6eO~Or%ta%q%ta%r%ta%s%tat%ta#e%ta#o%ta'n%ta!d%ta~P,<TO!c'kO!g'kO#o(sX'n(sX!d(sX~P%1oOv$mOw$nO!O$lOQ*aXR*aXS*aXT*aXU*aXj*aXk*aXl*aXo'zXp*aXx*aXz*aX}*aX!P*aX!Q'zX!Q*aX!R*aX!T*aX!X*aX!Y*aX!['zX![*aX!^*aX!_*aX!`*aX!a*aX!c'zX!d'zX!d*aX!e*aX!g'zX!i*aX!l*aX!o'zX!o*aX!t*aX!v*aX!x'zX!z*aX!|*aX#O*aX#P*aX#R*aX#T'zX#T*aX#V'zX#V*aX#X'zX#X*aX#[*aX#]*aX#^*aX#_*aX#a*aX%W'zX%Y'zX%Z'zX%]'zX%^'zX%_'zX%`'zX%a'zX%b'zX%c'zX%d'zX%e'zX%f'zX%g'zX%h'zX%i'zX%j'zX%k'zX%m'zX%n'zX%o'zX%p'zX%q'zX%r'zX%s'zX%u*aX%v*aX%w*aX%y'zX%y*aX%{*aX%|*aX%}*aX&O*aX&P*aX&Q*aX&T*aX&U*aX&V*aX&W*aX&X*aX&_*aX&a*aX&b*aX&c*aX&h*aX&i*aX&k*aX&w*aX&y*aX&{'zX&}*aX'O*aX'P*aX'R*aX'S*aX'U*aX'V*aX'W*aX't*aX(O*aX(]*aX*f*aX~Or'zXr*aX!x*aX%W*aX%Y*aX%Z*aX%]*aX%^*aX%_*aX%`*aX%a*aX%b*aX%c*aX%d*aX%e*aX%f*aX%g*aX%h*aX%i*aX%j*aX%k*aX%m*aX%n*aX%o*aX%p*aX%q*aX%r*aX%s*aX&{*aXt'zXt*aX#e'zX#e*aX#o'zX#o*aX'n'zX'n*aX~P,?eOr(YP!x(YP%W(YP%Y(YP%Z(YP%](YP%^(YP%_(YP%`(YP%a(YP%b(YP%c(YP%d(YP%e(YP%f(YP%g(YP%h(YP%i(YP%j(YP%k(YP%m(YP%n(YP%o(YP%p(YP%q(YP%r(YP%s(YP&{(YPt(YP#e(YP#o(YP'n(YP~P)>fO!Q5WO![5XO!o5WO!x5VO#T5VO#X5VO%]5UO%^5UO%_5WO%`5XO%a5QO%f5SO%i5YO~P&<aO!c4zO~P&?{Ov$mOw$nO!O$lO!Q5WO![5XO!o5WO!x5VO#T5VO#V&WO#X5VO%Z%wO%]5UO%^5UO%_5WO%`5XO%a5QO%b%zO%c%{O%d%|O%e%}O%f5SO%g&QO%h&RO%i5YO%j&UO%k&VO%m5]O%n5^O%o5_O%p5`O%y&iO&{6eO~Or&xa%W&xa%Y&xa%q&xa%r&xa%s&xat&xa#e&xa#o&xa'n&xa!d&xa~P,MSOo%TOt.eO!c%SOj&nXp&nXw&qX!O#YX!Q#YX![#YX!g#YX!o#YX!x#YX#T#YX#V#YX#X#YX%W#YX%Y#YX%Z#YX%]#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%m#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%y#YX&{#YX~P!M{Or!bi%q!bi%r!bi%s!bit!bi#e!bi#o!bi'n!bi!d!bi~P,<TOr%Vi%q%Vi%r%Vi%s%Vit%Vi#e%Vi#o%Vi'n%Vi!d%Vi~P,<TOr%Xi%q%Xi%r%Xi%s%Xit%Xi#e%Xi#o%Xi'n%Xi!d%Xi~P,<TOv$mOw$nO!O$lO%]5UO%y&iOr%[i!Q%[i![%[i!o%[i!x%[i#T%[i#V%[i#X%[i%W%[i%Y%[i%Z%[i%_%[i%`%[i%a%[i%b%[i%c%[i%d%[i%e%[i%f%[i%g%[i%h%[i%i%[i%j%[i%k%[i%m%[i%n%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[it%[i#e%[i#o%[i'n%[i!d%[i~O%^5UO~P-&xO!Q5WO![5XO!o5WO!x5VO#T5VO#X5VO%]5UO%^5UO%_5WO%`5XO~P'3SO!Q5WO![5XO!o5WO!x5VO#T5VO#X5VO%]5UO%^5UO%_5WO%`5XO%a5QO~P'6iO%^%[i~P-&xOv$mOw$nO!O$lO!x5VO#T5VO#X5VO%Z%wO%]5UO%^5UO%y&iOr%[i![%[i#V%[i%W%[i%Y%[i%`%[i%a%[i%b%[i%c%[i%d%[i%e%[i%f%[i%g%[i%h%[i%i%[i%j%[i%k%[i%m%[i%n%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[it%[i#e%[i#o%[i'n%[i!d%[i~O!Q%[i!o%[i%_%[i~P-+gO!Q5WO!o5WO%_5WO~P-+gOv$mOw$nO!O$lO!Q5WO![5XO!o5WO!x5VO#T5VO#X5VO%Z%wO%]5UO%^5UO%_5WO%`5XO%a5QO%b%zO%c%{O%d%|O%e%}O%y&iOr%[i#V%[i%W%[i%Y%[i%k%[i%m%[i%n%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[it%[i#e%[i#o%[i'n%[i!d%[i~O%f%[i%g%[i%h%[i%i%[i%j%[i~P-.qO%f5SO%g&QO%h&RO%i5YO%j&UO~P-.qOv$mOw$nO!O$lO!Q5WO![5XO!o5WO!x5VO#T5VO#X5VO%Z%wO%]5UO%^5UO%_5WO%`5XO%a5QO%b%zO%c%{O%d%|O%e%}O%f5SO%g&QO%h&RO%i5YO%j&UO%k&VO%y&iOr%[i%W%[i%Y%[i%m%[i%n%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[it%[i#e%[i#o%[i'n%[i!d%[i~O#V%[i~P-2RO#V&WO~P-2ROv$mOw$nO!O$lO!Q5WO![5XO!o5WO!x5VO#T5VO#V&WO#X5VO%Z%wO%]5UO%^5UO%_5WO%`5XO%a5QO%b%zO%c%{O%d%|O%e%}O%f5SO%g&QO%h&RO%i5YO%j&UO%k&VO%m5]O%y&iOr%[i%W%[i%Y%[i%o%[i%p%[i%q%[i%r%[i%s%[i&{%[it%[i#e%[i#o%[i'n%[i!d%[i~O%n%[i~P-5VO%n5^O~P-5VOv$mOw$nO!O$lO!Q5WO![5XO!o5WO!x5VO#T5VO#V&WO#X5VO%Z%wO%]5UO%^5UO%_5WO%`5XO%a5QO%b%zO%c%{O%d%|O%e%}O%f5SO%g&QO%h&RO%i5YO%j&UO%k&VO%m5]O%n5^O%o5_O%y&iOr%[i%q%[i%r%[i%s%[it%[i#e%[i#o%[i'n%[i!d%[i~O%W%[i%Y%[i%p%[i&{%[i~P-8ZO%W4}O%Y5OO%p5`O&{6eO~P-8ZO%q&XOr%[i%r%[i%s%[it%[i#e%[i#o%[i'n%[i!d%[i~P,<TO!d1uO~O!c*Xa!d*Xa!g*Xa~P%1oO!d3UO~O!d3VO~Or%Xq%q%Xq%r%Xq%s%Xqt%Xq#e%Xq#o%Xq'n%Xq!d%Xq~P,<TOr&zq%W&zq%Y&zq%q&zq%r&zq%s&zqt&zq#e&zq#o&zq'n&zq!d&zq~P,MSO!c#gi!g#gi~P+8pOr#giv#giw#gi!O#gi!Q#gi![#gi!c!fi!g!fi!o#gi!x#gi#T#gi#V#gi#X#gi%W#gi%Y#gi%Z#gi%]#gi%^#gi%_#gi%`#gi%a#gi%b#gi%c#gi%d#gi%e#gi%f#gi%g#gi%h#gi%i#gi%j#gi%k#gi%m#gi%n#gi%o#gi%p#gi%q#gi%r#gi%s#gi%y#gi&{#git#gi#e#gi#o#gi'n#gi!d#gi~Or&zy%W&zy%Y&zy%q&zy%r&zy%s&zyt&zy#e&zy#o&zy'n&zy!d&zy~P,MSO!c4zO~P?fOQ]OR6bOS6nOT4tOU$OOjQOkROlROp4{OxXOzSO}VO!OmO!P$eO!Q4yO!R$eO!T$fO!X$eO!Y6^O![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6_O!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u4yO%v4yO%w#XO%y6aO%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~Ow%rO~P-BdOQ]OR6bOS6nOT4tOU$OOjQOkROlROp4{Ow%]OxXOzSO}VO!OmO!P$eO!Q4yO!R$eO!T$fO!X$eO!Y6^O![^O!^`O!_aO!`bO!acO!iiO!llO!o6_O!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u4yO%v4yO%w#XO%y6aO%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~O!ehOr&RXv&RX!x&RX%W&RX%Y&RX%Z&RX%]&RX%^&RX%_&RX%`&RX%a&RX%b&RX%c&RX%d&RX%e&RX%f&RX%g&RX%h&RX%i&RX%j&RX%k&RX%m&RX%n&RX%o&RX%p&RX%q&RX%r&RX%s&RX&{&RXt&RX#e&RX#o&RX'n&RX!d&RX~P-GtOQ]OR#dOS#kOT#}OU$OOkROlROwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$POr(YPv(YPw(YP!O(YP!Q(YP!o(YP!x(YP#T(YP#V(YP#X(YP%W(YP%Y(YP%Z(YP%](YP%^(YP%_(YP%`(YP%a(YP%b(YP%c(YP%d(YP%e(YP%f(YP%g(YP%h(YP%i(YP%j(YP%k(YP%m(YP%n(YP%o(YP%p(YP%q(YP%r(YP%s(YP%y(YP&{(YPt(YP#e(YP#o(YP'n(YP!d(YP~Oj5gOp(zO!e6hO&d(|O&e(}O&f)OO~P. `Oj5hOp%XO!e6iO~P. `O#e6QO~P#JQO#e6XO~P&LeO!e6rO~P%'kO!d6[O~O!d6ZO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e6rO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%u#YO%v#YO%w#XO%y#[O%{#]O%|#^O%}#_O&O#`O&P#aO&Q#bO&T#eO&U#fO&V#gO&W#hO&X#iO&_#pO&a#rO&b#sO&c#tO&h#vO&i#wO&k#yO&w$RO&y$TO&}$VO'O$WO'P$XO'R$[O'S$]O'U$`O'V$aO'W$bO'tvO(OUO(]qO*f$PO~OwnO~P.*kOk6qO!e)eO#R!OO~O#sx#n!R!P%vp!Yjkl!X#c!l%Y%_%y!l!Q!o%]!T#R#T#V#X!x!O%]~",
  goto: "&.u*wPPPPPPPPPPPPPPPPPPPPPPPP*x*xPPP*{+qPP,gP,jP,jPPP-`P-`-`PPPPP0vP5Z8h;uPP;xP?YPPPP?YPPPBbPElPH|?YPISLaP?Y?Y?Y?YP?YP?YP?YP?YP?YPP! qP!&UP?YP?YP!)d?YPPPPISP!,oP!,|P!-g!._!0vP!1X!4aP!4jPP!4aPPP!8Y!4aP!4aP!4aP!4aP!4a!4aP!4aP!4aPPP!4a!4aP!9O!4a!9UPPPPPP!4a!9cP!9iP!4a!4a!9u!:OP!4a!4a!4aP!4a!4a!:q!4aPPPPP!4a!4a!4a!4aPP!:zPPP?YP?YPP?YPPPPPPPPPPPPPPP!;PPPPPPPP?YPPP?YP?YPPPPPP?Y?YPPPPP?Y!<d?Y!?n?YP?YPPPPPP?YPP?YP!Bv?Y!B}?Y?Y!FY?Y?Y?Y!Ib?YP?YP?YP?YPPP?YPP?YPPPP!Ll!NU!N[!No!Nu!N|# e# k# q#!r#!y##g##m##{#$V#$c#$i#&[#'yPPPPPPPPPPPP#(P#(u#,z#0n#4UP#4q#8X#?R#Bf#FS#FS#FS#I[#Ld$ p$#X$$iP$'u$*}$.V$1_$4g$4y$4y$8R$;i$;i$;i$;i$>u$>x$?O$Ba$Bd$Bq$Bz$FP$FY$Fc$Fu$Fy$Ga$Gd$Gh$Gn$Gr$G{$HO$HOHv$HR$HY$Hf$IV$I`$Ii$Il$Iy$J]$Jr$KX$KX$Kn$Kt$Kz$LX$LX$LX$LX$LXP$Le$Le$Ln$Ls$Ls$Ls$Lx$Nm$Nm$Nm$Nm%!^%!^%#y%%d%&y%'r%'r%(i%+s%+s%+s%+s%+s%+s%.{%2V%2V%2V%2V%2V%5_%8i%8m%8v%8v%8v%<Q%<U%<U%<U%<_%<g%<g%?q%?uP%CR%F]%Ig%Lq%Lq%Lq& y& }&%V&%V&(_&(b&+j&+j&+j&.rQ$kP!g$xUq$j$v$z&l&m&o&q&r&t)r*[*]+i+j+m+n+p+s+t+x+y+z.u/X/^/f/i/l/n2T2W3g!g$tUq$j$v$z&l&m&o&q&r&t)r*[*]+i+j+m+n+p+s+t+x+y+z.u/X/^/f/i/l/n2T2W3gR1r.s!g$wUq$j$v$z&l&m&o&q&r&t)r*[*]+i+j+m+n+p+s+t+x+y+z.u/X/^/f/i/l/n2T2W3g'yYOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*S*V*h*j+R+e,`,c,n-`-o-s-t-y-{-|.O.Q.V.n.o/T0R0V0Y0]0|1P1U1_1n1o2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s!f$xUq$j$v$z&l&m&o&q&r&t)r*[*]+i+j+m+n+p+s+t+x+y+z.u/X/^/f/i/l/n2T2W3gS&x!O4rQ&z!PQ&|!QQ'Q!RS)m$f4xT)x$m$|'g]Ohmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'S'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,U,`-`-o-s-t-y-{-|.O.Q.V/T/v0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s'g[Ohmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'S'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,U,`-`-o-s-t-y-{-|.O.Q.V/T/v0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sR*a%P'm_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`,c,n-`-o-s-t-y-{-|.O.Q.V/T0R0V0Y0]0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s']$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s'akOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s'`kOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sQ,p'hR2l0]Q%ajR*q%b'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sV(t#q(v4s'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sU(t#q(v4sR,l'e'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s!f$xUq$j$v$z&l&m&o&q&r&t)r*[*]+i+j+m+n+p+s+t+x+y+z.u/X/^/f/i/l/n2T2W3gQ)d$ZQ)g$_Q)j$dQ.W)eQ.X)hQ.Y)kR6q6t'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sQ)j$dR.Y)k'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sR,k'eS'z!g%_Q-Q'vQ/{,XR0b,z!P's!g%_'t'v'z'|,X,}-O-Q-S-V-X/y/{/}0d0f0g2_2`2b3kS'{!g%_S,|'t'|Q-R'vU/|,X-O-SQ0`,xS0e,}-XU2^/y/}0gQ2m0dS3l2_2bR4Y3kt'q!g%_'t'v'|,X,x,}-O-S-X/y/}0d0g2_2b3kQ(R!qQ(S!rQ(T!sQ(Y!uQ([!vW(p#k#l6n6oS(r#n6pS)x$m$|Q*b%RQ*|%tQ,_'YQ,b'ZQ-^(UQ-_(VS-a(W(]Q.R)ZQ.c)xQ0Q,`Q0w-bS1^.V6kQ2e0RQ2o0iQ2z0xQ3S1]Q3T1_Q3W1eS3n2f2gQ3x2{R4]3oS'|!g%_Q,}'tQ-S'vS/},X-OR2_/y^!wOn$h%W%p'x*hS'y!g%_Q(X!tQ(g#PU(q#l#|6oW)P#u({6c6hS)W#x6dS)`$Q4uS)a$S4vQ,Z'WQ-P'vQ-T'wS-W'z'{Q-Z(RQ-[(SQ-](TQ-g(YQ-j([Q-l(aS.Q)U6iU/z,X-Q-RQ0O,[S0c,|-VQ0r-^Q0s-_Q0v-aU2a/{/|0fQ2n0eQ2r0mQ2y0wS3j2^2`Q3r2mQ3s2oQ3w2zQ3z2}Q4Z3lQ4_3uQ4a3xQ4h4YQ4p4lR4q4o_#WOn$h%W%p'x*h'[#mOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sQ'P!QQ'W![S'Y!_!`Q'j!cQ)Z#zQ0R,cR1].TW(p#k#l6n6oS(r#n6pQ*|%tQ,_'YQ0Q,`S1^.V6kQ2e0RQ3T1_S3n2f2gR4]3oQ'v!gR,X'US!pO$hU%in%p'xT*f%W*hX0j-Z-[0k0oQ0n-ZQ0p-[Q2q0kR2s0o_!tOn$h%W%p'x*hQ(c!wQ-f(XQ0q-]Q0{-gQ1O-jQ2t0rQ2u0sQ2x0vQ3v2yQ4`3wR4k4a_!yOn$h%W%p'x*hV%nn%p'x![&bp%Y%e%g'}(j(n)c*c+O+P+^+_+`+a+b+c,a-h.y/S/U0t1X1Y1v4|5e6T!c5[)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j5d5k5m5n5o5z5{5|5}6O6P6W6Y6]6j%S#nOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X6p$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6e']#oOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sS)x$m$|R1e.d'[#zOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sR.T)[']#|Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s%S$QOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X4u$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6eQ$vUQ&lqQ)r$jr*Y$v&l)r*[+i+m+p+s+y.u/X/^/f/l/n2T3gQ*[$zQ+i&mQ+m&oQ+p&qQ+s&rQ+y&tQ.u*]Q/X+jQ/^+nQ/f+tQ/l+xQ/n+zQ2T/iR3g2WQ*R$sR.l*Rb$pTWjsuxz}+vS)|$p.fT.f)}.hQ.h)}R1g.hS%OZ,SR*_%O[*k%Y%e-h0t1X1YQ-p(nQ-w4|W.z*k-p-w/RR/R5eQ*o%`R.{*oQ/w,VR2]/wS't!g%_f,{'t-O-V-X/y0d0f0g2`2b3kQ-O'vQ-V'zQ-X'|Q/y,XQ0d,}Q0f-QQ0g-SQ2`/{Q2b/}R3k2_S%pn'xR*y%pd%Uf%X'i(z)b)z.a4{5j5lW*e%U,Q,Y,]S,Q'O)YQ,Y'VR,]'XQ0Z,oR2k0ZQ'm!dU,t'm-Y1QQ-Y(OR1Q-qQ0k-ZQ0o-[T2p0k0o^!xOn$h%W%p'x*hR(e!xQ*h%WR.w*h!f&Pp%Y%e%g'}(j(n)])c*c+O+P+U+Z+[+]+^+_+`+a+b+c,a-h.y/S/U0t1X1Y1v4|5e6TS+T&P5R!m5R)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j5d5i5k5m5n5o5s5w5x5y5z5{5|5}6O6P6W6Y6]6j!b&Tp%Y%e%g'}(j(n)])c*c+O+P+[+]+^+_+`+a+b+c,a-h.y/S/U0t1X1Y1v4|5e6TS+V&T5T!i5T)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j5d5i5k5m5n5o5x5y5z5{5|5}6O6P6W6Y6]6jQ$hOR)o$h!g$yUq$j$v$z&l&m&o&q&r&t)r*[*]+i+j+m+n+p+s+t+x+y+z.u/X/^/f/i/l/n2T2W3g'`ZOhmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s!f$xUq$j$v$z&l&m&o&q&r&t)r*[*]+i+j+m+n+p+s+t+x+y+z.u/X/^/f/i/l/n2T2W3gV,S'S,U/v'l_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`,c,n-`-o-s-t-y-{-|.O.Q.V/T0R0V0Y0]0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sQ.m*SQ.q*VQ1k.nQ1l.oQ3Z1oR3[1n'yTOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*S*V*h*j+R+e,`,c,n-`-o-s-t-y-{-|.O.Q.V.n.o/T0R0V0Y0]0|1P1U1_1n1o2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sQ$rTQ${WQ%bjQ&nsQ&puQ&sxQ&uzQ&w}R/h+v'yWOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*S*V*h*j+R+e,`,c,n-`-o-s-t-y-{-|.O.Q.V.n.o/T0R0V0Y0]0|1P1U1_1n1o2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s[pO$h%W%p'x*hQ%Yhr%em%Z%]%r'p(Q({)U-s-y.O.Q6f6h6i6r6sQ%gnW%so#Y4y6_S'}!j'lQ(j#ZS(k#[6a`(n#k#l#n.V6k6n6o6pQ)]#}Q)c$UQ)t$lQ){$nQ*c%SQ*r%dQ+O%vQ+P%xS+Q%y&]Q+S&OQ+U&SQ+W&[Q+X&^Q+Y&_Q+Z&`Q+[&aQ+]&bQ+^&cQ+_&dQ+`&eQ+a&fQ+b&gQ+c&hQ+d&jQ+}&yQ,O&{Q,P&}Q,R'RQ,a'ZQ-h(ZQ-v(xQ.Z)nQ.`)uQ.b)vS.y*j-oQ/S+RQ/U+eQ0t-`S1S-t6SQ1X-{Q1Y-|Q1v/TQ2h0VQ2|0|Q3P1UQ3t2vQ4b3yQ4j4^`4|#u#x)S)T)W5h6c6d`5c#d$Q$S(q1P4u4v6bQ5d6``5e%t'Y,`0R1_2f2g3oQ5i4tQ5k4wQ5m4zQ5n4}Q5o5OS5p5P5VQ5r5QQ5s5SQ5t5UQ5u5WQ5v5XQ5w5YQ5x5ZQ5y5[Q5z5]Q5{5^Q5|5_Q5}5`Q6O5aQ6P5bQ6T6gQ6W5qQ6Y6QQ6]6XR6j6e'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sS'T!X%^S,T'S/vR/u,U'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sQ,d'^Q,h'bQ,k'eU,m'h0Y0]Q0R,cR0X,n']dOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s']eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sT,e'`'bS%[h%ZS%fm-{U%hn%]-|S)Q#u6cS)V#x6dQ*{%rW,w'p(Q(Z-`Q-x({Q-z)SU-})T)W5hQ.P)UQ1R-sQ1W-yS1Z.O.QQ6R6fQ6U6hQ6V6iQ6l6rR6m6sW'l!d'm(O-Yb*j%Y%e*k-h/R0t1X1Y5eQ,c'[W-o(n-p-w4|Q.V)dS/v,V/wQ0V,kS0Y,o0ZS1P-q1QQ1U-uQ1_.WQ2f0RQ3o2gQ6S._R6k6q'ejOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'h'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0]0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s']sOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s']uOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s']xOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s']zOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sQ+x&tU/i+w+y+zQ/o+{S2W/m/nR2Y/p']}Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s^!XOn$h%W%p'x*h&|%^hmo!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$l$n%S%Z%]%d%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p(Q(Z(q(x({)S)T)U)W)n)u)v*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sQ(^!vQ-c(WQ-k(_R0y-d'e!WOhmno!j!v#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(W(Z(_(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-d-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sR,W'SQ,V'SR2[/v^!gOn$h%W%p'x*h'S%_hmo!j#Y#Z#[#d#k#l#n#q#u#x#}$Q$S$U$l$n%S%Z%]%d%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p(Q(Z(q(v(x({)S)T)U)W)n)u)v*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4s4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sT'U!X!hR,z'rS$gO$hU%on%p'xT*g%W*h_![On$h%W%p'x*hQ'o!eQ(b!wQ(f!yQ*u%iQ*v%mQ*}%uQ,Z'WQ,^'YQ,g'bQ,i'cQ,r'jQ-P'vS-e(X(cQ-i(ZQ.v*fS/O*w*xU/z,X-Q-RQ0O,[S0P,_,`Q0S,dQ0T,fQ0U,hQ0W,lQ0[,pQ0u-`Q0z-fQ0|-hQ0}-iQ1t/PU2a/{/|0fQ2c0QQ2d0RQ2v0tQ2w0uS3j2^2`U3m2e2f2gQ3p2hQ3q2lQ3y2|Q4Z3lS4[3n3oQ4^3tQ4h4YR4i4]_!_On$h%W%p'x*h_!`On$h%W%p'x*hq(o#k#l#n%t'Y,`.V0R1_2f2g3o6k6n6o6pT'[!_!`^!qOn$h%W%p'x*h^%tp!p%g%i%m*f*xT'Z!_!`R'^!_T'`!_!`Q,f'`R,h'bT'b!_!`_!cOn$h%W%p'x*hR'e!_R'h!_S,o'h0]R2j0Y^!eOn$h%W%p'x*hR-r(q^!dOn$h%W%p'x*hQ(O!jS(m#d6bS)`$Q4uS)a$S4vS,s'l1PR-q(q_!hOn$h%W%p'x*h_!jOn$h%W%p'x*hR(P!jY%up!p%g%i*fQ*w%mR/P*x^!rOn$h%W%p'x*h_%tp!p%g%i%m*f*x^!sOn$h%W%p'x*h^%tp!p%g%i%m*f*xR(U!t^!uOn$h%W%p'x*h^%tp!p%g%i%m*f*xR(V!t^!vOn$h%W%p'x*h^%tp!p%g%i%m*f*xR(W!tX0i-Z-[0k0oX0m-Z-[0k0og(a!w(X-]-g-j0r0s0v2y3w4a^#POn$h%W%p'x*hR'w!g_#VOn$h%W%p'x*hV%on%p'xV%mn%p'x!l%yp%Y%e%g'}(j(n)])c*c+O+P+S+U+X+Y+Z+[+]+^+_+`+a+b+c,a-h.y/S/U0t1X1Y1v4|5e6T!s5P)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j5d5i5k5m5n5o5r5s5u5v5w5x5y5z5{5|5}6O6P6W6Y6]6j!h&Op%Y%e%g&P'}(j(n)])c*c+O+P+U+Z+[+]+^+_+`+a+b+c,a-h.y/S/U0t1X1Y1v4|5e6T!o5Q)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j5R5d5i5k5m5n5o5s5w5x5y5z5{5|5}6O6P6W6Y6]6j!d&Sp%Y%e%g&T'}(j(n)])c*c+O+P+[+]+^+_+`+a+b+c,a-h.y/S/U0t1X1Y1v4|5e6T!k5S)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j5T5d5i5k5m5n5o5x5y5z5{5|5}6O6P6W6Y6]6j!b&`p%Y%e%g'}(j(n)])c*c+O+P+[+]+^+_+`+a+b+c,a-h.y/S/U0t1X1Y1v4|5e6T!i5Y)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j5d5i5k5m5n5o5x5y5z5{5|5}6O6P6W6Y6]6j!^&ap%Y%e%g'}(j(n)c*c+O+P+]+^+_+`+a+b+c,a-h.y/S/U0t1X1Y1v4|5e6T!e5Z)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j5d5k5m5n5o5y5z5{5|5}6O6P6W6Y6]6jp&gp%Y%e%g'}(n+c,a-h.y0t1X1Y4|5e6Tw5a)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j6P6jn&hp%Y%e%g'}(n,a-h.y0t1X1Y4|5e6Tu5b)t){*r+d+},O,P,R.Z.`.b2h2|3P3t4b4j6j%S#ZOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X6`$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6e']#cOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s%S#lOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X6o$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6e']#jOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s%S#qOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X4s$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6eT(w#q4sQ(u#qQ-u(vR._4s%S#uOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X6c$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6eT)R#u6cW)P#u({6c6hR)_$OS)S#u6cT-y({6h%S#xOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X6d$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6eT)X#x6d'[#{Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sT)y$m$|%S$SOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X4v$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6e%S$UOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X4w$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6e%S$ZOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R1P1_2f2g3o5h6c6d6f6g6h6i6k6n6o6p6r6s#X6t$l$n%d&j&y&{&}'R)n)u)v0V0|1U2v3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5q6Q6S6X6_6`6a6b6e']$YOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sT)f$Z6t']$_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s']$^Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sR)i$_']$dOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6s']$cOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'p'x(Q(Z(q(x({)S)T)U)W)n)u)v*h*j+R+e,`-`-o-s-t-y-{-|.O.Q.V/T0R0V0|1P1U1_2f2g2v3o3y4^4t4u4v4w4y4z4}5O5P5Q5S5U5V5W5X5Y5Z5[5]5^5_5`5a5b5h5q6Q6S6X6_6`6a6b6c6d6e6f6g6h6i6k6n6o6p6r6sR)l$d",
  nodeNames: "⚠ UnrestrictedIdentifier SpecialScalarVariable NamedUnaryOperator ListOperator FileTestOp IOOperatorStart Glob ReadonlySTDIN IOOperatorEnd HeredocStartIdentifier HeredocEndIdentifier InterpolatedStringContent EscapeSequence QuoteLikeStartDelimiter QuoteLikeSeparatorDelimiter QuoteLikeEndDelimiter StringContent QWElement RegexOptions PodDirective PodContent PodCut Comment UninterpolatedHeredocBody InterpolatedHeredocBody ScalarVariable ArrayVariable HashVariable PackageVariable PackageName :: Identifier PackageVariableName ] ArrayAccessVariable } HashAccessVariable ArrowOperator { StringSingleQuoted StringQQuoted q StringDoubleQuoted StringQqQuoted qq [ Integer ArithOp Float ScalarDereference $ PackageVariable PackageName PackageVariableName TypeGlob Option HeredocInitializer << SpecialLiteral __FILE__ __LINE__ __PACKAGE__ __SUB__ Pair FatComma ) ( List Comma QWList qw QWListContent ArrayLength $# ArrayRef HashRef ArithOp ArrayAccessVariable HashAccessVariable BacktickQuoted CommandQxQuoted qx PatternMatchM m PatternMatch / RegexQr qr SubstitutionS s TransliterationTrOrY tr y ArrayDereference @ HashDereference % FunctionDereference & TypeGlobDereference * Constant VariableDeclaration our state my local AnonymousFunction sub FunctionPrototype Prototype FunctionAttribute : FunctionSignature ParenthesizedArguments FunctionPrototypeAttribute prototype Block PackageStatement package PackageName Version ; UseNoStatement use no ModuleName Arguments UseNoIfStatement if UseLibStatement lib UseNoSubsStatement subs UseNoFeatureStatement feature UseNoVersion RequireStatement require UseConstantStatement constant UseParentOrBaseStatement parent base NoRequire ExpressionStatement FunctionDefinition async FunctionName SingleLineStatement ReturnExpression return unless while until for foreach IfStatement ElsifClause elsif ElseClause else UnlessStatement WhileStatement Label Continue continue UntilStatement ForStatement1 ForStatement2 \\ StandaloneBlock NamedBlockStatement NamedBlock SpecialBlock BEGIN UNITCHECK CHECK INIT END Ellipsis EmptyStatement PodStatement EndDataStatement __END__ __DATA__ LoopControlStatement next last redo Assignment = UpdateExpression UpdateOp x BinaryExpression ArithOp BindingOp ConcatOp BitOp CompareOp lt gt le ge CompareOp eq ne CompareOp cmp isa BitOp BitOp LogicOp LogicOp RangeOp and or xor UnaryExpression LogicOp RefOp not UpdateExpression ArithOp NoArgumentNamedUnaryOperator fork getpid time times wait wantarray NamedUnaryExpression ListOperatorExpression grep map join sort unpack CallExpression FunctionName CallExpressionWithBareword FunctionName Bless bless OutputFunction print say printf STDIN STDERR STDOUT SystemCall exec system MethodInvocation SUPER FunctionName IndirectMethodInvocation FunctionName CallExpressionRecursive ArrayFunction FunctionName FileTest IOOperator EvalExpression Eval DoExpression do GotoExpression goto TernaryExpression LogicOp ArrayModifierFunction push unshift splice ArrayPopOrShift pop shift HashOrArrayDestructureFunction each values keys Program",
  maxTerm: 452,
  context: contextTracker,
  nodeProps: [
    ["group", -64,2,26,27,28,40,41,43,44,47,49,50,52,55,56,57,59,64,68,70,73,75,76,78,79,80,81,83,85,87,89,91,94,96,98,100,102,103,108,191,193,196,220,224,226,233,234,240,242,244,246,253,256,259,261,262,264,265,266,268,270,272,274,278,281,"Expression",-26,119,124,129,131,133,135,137,138,140,142,146,147,150,158,163,164,168,169,170,172,173,175,181,182,183,184,"Statement"],
    ["closedBy", 6,"IOOperatorEnd",39,"}",46,"]",67,")"],
    ["openedBy", 9,"IOOperatorStart",34,"[",36,"{",66,"("],
    ["isolate", -2,23,40,""]
  ],
  skippedNodes: [0],
  repeatNodeCount: 19,
  tokenData: "!,_~RzXY#uYZ#u]^#upq#uqr#zrs$ast'qtu(Yuv+`vw.|wx0yxy;byz;gz{;l{|?_|}AO}!OAT!O!PFr!P!QIl!Q!RJP!R![Kg![!]NV!]!^Nd!^!_! Z!_!`! {!`!a!!`!a!b!!x!b!c!!}!c!}!&n!}#O!'P#O#P!'v#P#Q!(o#Q#R!)f#R#S!)q#S#T!*X#T#j!&n#j#k!*^#k#o!&n#o#p!+e#p#q!+j#q#r!+x#r#s!+}~#zO'x~~$PQ%u~!_!`$V#r#s$[~$[O%f~~$aO%^~~$fU(O~OY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~${UOY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~%bWOY$xZ!O$x!O!P%_!P#d$x#d#e%z#e;'S$x;'S;=`'k<%lO$x~%}WOY$xZ!O$x!O!P%_!P#a$x#a#b&g#b;'S$x;'S;=`'k<%lO$x~&jWOY$xZr$xrs'Ss!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~'XU#s~OY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~'nP;=`<%l$x~'vSg~OY'qZ;'S'q;'S;=`(S<%lO'q~(VP;=`<%l'q~(a_#c`!T~st)`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!c!}*Y!}#O)e#O#P)e#P#Q)e#R#S*Y#T#o*Y#o#p*k~)eO!l~`)jY#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~*_Sj~!Q![*Y!c!}*Y#R#S*Y#T#o*Y~*nR!c!}*w#R#S*w#T#o*w~*zT!Q![*w!c!}*w#R#S*w#T#o*w#q#r+Z~+`Oj~~+ga#c`#T~qr,ltu)euv)evw)ez{)e{|,q}!O,l!Q![-h!]!^)e!_!`-y!b!c)e!c!}-h!}#O)e#O#P.O#P#Q)e#R#S-h#T#o-h~,qOl~~,xYl~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~-mSl~!Q![-h!c!}-h#R#S-h#T#o-h~.OO%Y~~.TZ#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e#Q#R.v~.yP!c!},l~/T[#c`#V~tu)euv)evw/yz{)e{|)e!O!P0s!]!^)e!_!`-y!b!c)e!}#O)e#O#P)e#P#Q)e~0QZ%nQ#c`tu)euv)evw)ez{)e{|)e!]!^)e!_!`-y!b!c)e!}#O)e#O#P)e#P#Q)e~0vP!_!`-y~1OZx~OY0yYZ1qZw0ywx3cx!O0y!O!P6s!P#O0y#O#P7q#P;'S0y;'S;=`;[<%lO0y~1vVx~Ow1qwx2]x#O1q#O#P2b#P;'S1q;'S;=`3]<%lO1q~2bOx~~2eRO;'S1q;'S;=`2n;=`O1q~2sWx~Ow1qwx2]x#O1q#O#P2b#P;'S1q;'S;=`3];=`<%l1q<%lO1q~3`P;=`<%l1q~3hUx~OY3zZ!O3z!O!P4a!P;'S3z;'S;=`6m<%lO3z~3}UOY3zZ!O3z!O!P4a!P;'S3z;'S;=`6m<%lO3z~4dWOY3zZ!O3z!O!P4a!P#d3z#d#e4|#e;'S3z;'S;=`6m<%lO3z~5PWOY3zZ!O3z!O!P4a!P#a3z#a#b5i#b;'S3z;'S;=`6m<%lO3z~5lWOY3zZw3zwx6Ux!O3z!O!P4a!P;'S3z;'S;=`6m<%lO3z~6ZU#s~OY3zZ!O3z!O!P4a!P;'S3z;'S;=`6m<%lO3z~6pP;=`<%l3z~6x]x~OY0yYZ1qZw0ywx3cx!O0y!O!P6s!P#O0y#O#P7q#P#d0y#d#e8{#e;'S0y;'S;=`;[<%lO0y~7tWOY0yYZ1qZ!O0y!O!P6s!P;'S0y;'S;=`8^;=`<%l1q<%lO0y~8cWx~Ow1qwx2]x#O1q#O#P2b#P;'S1q;'S;=`3];=`<%l0y<%lO1q~9Q]x~OY0yYZ1qZw0ywx3cx!O0y!O!P6s!P#O0y#O#P7q#P#a0y#a#b9y#b;'S0y;'S;=`;[<%lO0y~:OZx~OY0yYZ1qZw0ywx:qx!O0y!O!P6s!P#O0y#O#P7q#P;'S0y;'S;=`;[<%lO0y~:xU#s~x~OY3zZ!O3z!O!P4a!P;'S3z;'S;=`6m<%lO3z~;_P;=`<%l0y~;gO!e~~;lO!d~~;s_#c`#X~tu)euv)evw)ez{<r{|)e!]!^)e!_!`-y!b!c)e!c!}=l!}#O)e#O#P)e#P#Q)e#R#S=l#T#o=l#o#p>g~<yZ#c`%]~tu)euv)evw)ez{)e{|)e!]!^)e!_!`-y!b!c)e!}#O)e#O#P)e#P#Q)e~=qT!X~!Q![=l![!]>Q!c!}=l#R#S=l#T#o=l~>TP![!]>W~>ZS!c!}=l#R#S=l#T#o=l#o#p>g~>jR!c!}>s#R#S>s#T#o>s~>vT!Q![>s!c!}>s#R#S>s#T#o>s#q#r?V~?[P!X~![!]>Q~?fZ#c`!o~tu)euv)evw)ez{)e{|@X!]!^)e!_!`-y!b!c)e!}#O)e#O#P)e#P#Q)e~@`Y#c`%y~tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~ATO!g~~AYW!Qk}!OAr!_!`-y!`!aAw!c!}A|#R#SA|#T#bA|#b#cB_#c#oA|~AwO%y~~A|Ov~kBRS!Yk!Q![A|!c!}A|#R#SA|#T#oA|oBdU!Yk!Q![A|!c!}A|#R#SA|#T#cA|#c#dBv#d#oA|oB{U!Yk!Q![A|!c!}A|#R#SA|#T#fA|#f#gC_#g#oA|oCdU!Yk!Q![A|!c!}A|#R#SA|#T#XA|#X#YCv#Y#oA|oC{U!Yk!Q![A|!c!}A|#R#SA|#T#eA|#e#fD_#f#oA|oDdU!Yk!Q![A|!c!}A|#R#SA|#T#iA|#i#jDv#j#oA|oD{U!Yk!Q![A|!c!}A|#R#SA|#T#]A|#]#^E_#^#oA|oEdU!Yk!Q![A|!c!}A|#R#SA|#T#fA|#f#gEv#g#oA|oE{U!Yk!Q![A|!c!}A|#R#SA|#T#XA|#X#YF_#Y#oA|oFfS$VS!Yk!Q![A|!c!}A|#R#SA|#T#oA|~FyS#n[%_Q!O!PGV!Q![HX!_!`-y#R#SGy_G^R%pQ#n[!O!PGg!Q![Gy#R#SGy_GpR)eP%pQ#n[!O!PGy!Q![Gy#R#SGy[HOR#n[!O!PGy!Q![Gy#R#SGy~H`T#n[!R~!O!PGy!Q![HX!g!hHo#R#SI^#X#YHo~HrR{|H{}!OH{!Q![IR~IOP!Q![IR~IWQ!R~!Q![IR#R#SH{~IcR#n[!O!PGy!Q![HX#R#SGy~IqQ!x~!P!QIw!_!`-y~I|P%o~!_!`-y~JW[#n[!P~!O!PHX!Q!YJ|!Y![Kg!d!eLn!g!hHo!q!rMV!z!{Mh#R#SK}#U#VLn#X#YHo#c#dMV#l#mMh~KTU#n[!P~!O!PHX!Q!YJ|!Y![Kg!g!hHo#R#SL]#X#YHo~KnT#n[!P~!O!PHX!Q![Kg!g!hHo#R#SK}#X#YHo~LSR#n[!O!PGy!Q![Kg#R#SGy~LbS#n[!O!PGy!Q!YJ|!Y![Kg#R#SGy~LqQ!Q!RLw!R!SLw~L|R!P~!Q!RLw!R!SLw#R#SLn~MYP!Q!YM]~MbQ!P~!Q!YM]#R#SMV~MkR!Q![Mt!c!iMt#T#ZMt~MyS!P~!Q![Mt!c!iMt#R#SMh#T#ZMt~N[P#e~![!]N_~NdOo~oNkY#o_#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~! `Q%a~!^!_! f!_!`! n~! kP![~!_!`-y~! sP%a~!`!a! v~! {O%i~~!!QR%W~!_!`$V!`!a!!Z#r#s$[~!!`O!c~~!!eQ%a~!_!`!!k!`!a!!p~!!pO%a~~!!uP%`~!_!`-y~!!}O&{~~!#Uc#c`#R~qr!$atu)euv)evw)ez{)e{|!$f|!Q!$a!Q![!%]![!]!$a!]!^!$f!^!b!$a!b!c!$f!c!}!%]!}#O!$f#O#P!%n#P#Q!$f#Q#R!$a#R#S!%]#T#o!%]~!$fOk~~!$mYk~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!%bSk~!Q![!%]!c!}!%]#R#S!%]#T#o!%]~!%uZk~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e#Q#R!&h~!&kP!c!}!$a~!&sSp~!Q![!&n!c!}!&n#R#S!&n#T#o!&n~!'WY#c`!O~tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)eo!(PY$qS%vk#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)ec!(vYrR#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!)kQ%m~!O!P0s!_!`-y~!)xT#n[p~!O!PGy!Q![!)q!c!}!&n#R#S!)q#T#o!&n~!*^O(]~~!*cTp~!O!P!*r!Q![!*}!c!}!&n#R#S!&n#T#o!&n[!*wQ#n[!O!P!*r!Q![!*r~!+UT#n[p~!O!P!*r!Q![!*}!c!}!&n#R#S!&n#T#o!&n~!+jOw~~!+oR%m~!O!P0s!_!`-y#p#qIw~!+}Ot~~!,SQ%u~!O!P!,Y#r#s! v~!,_O%u~",
  tokenizers: [semicolon, unrestrictedIdentifier, specialScalarVariable, builtinOperator, fileIO, heredoc, interpolated, quoteLikeOperator, regex, pod, endData, 0, 1, 2, 3, 4],
  topRules: {"Program":[0,285]},
  dynamicPrecedences: {"151":1,"184":4,"267":1,"318":1,"320":1,"323":1,"327":1,"328":1,"329":1,"330":1,"334":1,"336":1,"337":1,"338":1,"339":1,"341":1,"342":1,"344":1,"345":1,"346":1,"347":1,"350":1,"351":1,"353":1,"355":1,"356":1,"359":1,"360":1,"361":1,"363":1,"364":1,"365":1,"366":1,"367":1,"372":1,"373":1,"376":1,"377":1,"378":1,"379":1,"380":1,"381":1,"382":1,"383":1,"384":1,"385":1,"386":1,"387":1,"388":1,"390":1,"391":1,"393":1,"394":1,"395":1,"396":1,"397":1,"398":1,"399":1,"400":1,"401":1,"402":1,"403":1,"404":1,"405":1,"406":1,"407":1,"408":1,"409":1,"410":1,"411":1,"412":1,"413":1,"414":1,"416":1,"417":1,"418":1,"419":1,"420":1,"421":1,"424":1,"425":1,"426":1,"428":1,"429":1,"430":1,"432":1,"433":1,"435":1,"437":1,"438":1,"439":1,"440":1,"441":1,"442":1,"444":1,"445":1,"446":1,"448":1,"449":1,"450":1,"451":1},
  specialized: [{term: 32, get: (value) => spec_Identifier[value] || -1}],
  tokenPrec: 28206
});

const perlLanguage = language.LRLanguage.define({
    name: 'perl',
    parser: parser.configure({
        props: [
            language.indentNodeProp.add({
                IfStatement: language.continuedIndent({ except: /^\s*({|else\b|elsif\b)/ }),
                Block: language.delimitedIndent({ closing: '}' }),
                String: () => null,
                Statement: language.continuedIndent()
            }),
            language.foldNodeProp.add({
                'Block Array ArrayRef HashRef': language.foldInside,
                'InterpolatedHeredocBody UninterpolatedHeredocBody': (node) => {
                    if (node.prevSibling && node.lastChild?.prevSibling)
                        return { from: node.prevSibling.to, to: node.lastChild.prevSibling.to };
                    return null;
                },
                PodStatement(node) {
                    if (node.firstChild?.type.name === 'PodDirective' &&
                        node.firstChild.nextSibling?.type.name === 'PodContent')
                        return { from: node.firstChild.nextSibling.from, to: node.firstChild.nextSibling.to };
                    return null;
                }
            }),
            highlight.styleTags({
                'do continue else elsif for foreach goto if last next redo return unless until when while': highlight.tags.controlKeyword,
                'bless local my our state sub': highlight.tags.definitionKeyword,
                'package use no import require parent base': highlight.tags.moduleKeyword,
                'constant feature lib subs async prototype': highlight.tags.modifier,
                'NamedUnaryOperator ListOperator Eval each exec fork getpid grep': highlight.tags.function(highlight.tags.keyword),
                'join keys map pop print printf push say shift sort splice system time times': highlight.tags.function(highlight.tags.keyword),
                'unpack unshift values wait wantarray': highlight.tags.function(highlight.tags.keyword),
                'BEGIN CHECK END INIT UNITCHECK': highlight.tags.processingInstruction,
                '__FILE__ __LINE__ __PACKAGE__ __SUB__': highlight.tags.literal,
                'ScalarVariable SpecialScalarVariable ArrayVariable HashVariable': highlight.tags.variableName,
                'ArrayLength/Identifier Prototype Constant/Identifier': highlight.tags.variableName,
                'PackageVariable/PackageVariableName/...': highlight.tags.variableName,
                'PackageName/Identifier PackageName/UnrestrictedIdentifier PackageName/ScalarVariable': highlight.tags.namespace,
                'PackageName/ArrayVariable PackageName/HashVariable SUPER': highlight.tags.namespace,
                'NamedType/...': highlight.tags.typeName,
                Name: highlight.tags.name,
                'Label/Identifier LabelName/Identifier STDIN STDERR STDOUT IOOperator/Identifier': highlight.tags.labelName,
                'MemberExpression/Identifier': highlight.tags.propertyName,
                'MemberExpression/ScalarVariable': highlight.tags.special(highlight.tags.propertyName),
                'FunctionName/PackageName/... FunctionName/Identifier': highlight.tags.function(highlight.tags.definition(highlight.tags.variableName)),
                UpdateOp: highlight.tags.updateOperator,
                'ArithOp "*" % "/"': highlight.tags.arithmeticOperator,
                'LogicOp and not or xor : FileTestOp': highlight.tags.logicOperator,
                BitOp: highlight.tags.bitwiseOperator,
                '<<': highlight.tags.special(highlight.tags.bitwiseOperator),
                'CompareOp < lt gt le ge eq ne cmp isa': highlight.tags.compareOperator,
                '=': highlight.tags.definitionOperator,
                '$ $# @ % & "*" ArrowOperator \\': highlight.tags.derefOperator,
                'ScalarDereference/{ ScalarDereference/}': highlight.tags.derefOperator,
                'ArrayDereference/{ ArrayDereference/}': highlight.tags.derefOperator,
                'HashDereference/{ HashDereference/}': highlight.tags.derefOperator,
                'FunctionDereference/{ FunctionDereference/}': highlight.tags.derefOperator,
                'TypeGlobDereference/{ TypeGlobDereference/}': highlight.tags.derefOperator,
                'ConcatOp BindingOp RangeOp RefOp x': highlight.tags.operator,
                Comment: highlight.tags.lineComment,
                Integer: highlight.tags.integer,
                Float: highlight.tags.float,
                'StringSingleQuoted StringDoubleQuoted q qq qx */StringContent */InterpolatedStringContent': highlight.tags.string,
                '*/QuoteLikeStartDelimiter QuoteLikeSeparatorDelimiter */QuoteLikeEndDelimiter': highlight.tags.string,
                'qw QWListContent/... Pair/Identifier HashAccessVariable/Identifier Version': highlight.tags.string,
                'HeredocInitializer/... HeredocEndIdentifier Glob': highlight.tags.string,
                'm qr s tr y RegexOptions': highlight.tags.special(highlight.tags.string),
                'PodStatement EndDataStatement/...': highlight.tags.blockComment,
                EscapeSequence: highlight.tags.escape,
                'Comma FatComma': highlight.tags.punctuation,
                '( )': highlight.tags.paren,
                '[ ]': highlight.tags.squareBracket,
                '{ }': highlight.tags.brace,
                '; :: :': highlight.tags.separator
            })
        ]
    }),
    languageData: { commentTokens: { line: '#' } }
});
const perlCompletion = perlLanguage.data.of({
    autocomplete: autocomplete.completeFromList([
        { label: 'my', type: 'keyword' },
        { label: 'use', type: 'keyword' },
        { label: 'sub', type: 'keyword' }
    ])
});
const perl = () => new language.LanguageSupport(perlLanguage, [perlCompletion]);

exports.perl = perl;
exports.perlCompletion = perlCompletion;
exports.perlLanguage = perlLanguage;
